
####################################################################
##  R Functions for Lexicoder Sentiment Dictionary Pre-Processing  #
####################################################################

## Adapted for R from the original Lexicoder Pre-Processing Scripts
     ## by Emily Luxon (eoluxon@umich.edu),

##Version 1.0, released on 1 December 2017

## For information on the LSD, and the original Pre-Processing Scripts,
## please visit http://www.lexicoder.com/

## The citation for the LSD is:
## Young, L., and Soroka, S.  2012. "Affective News: The Automated Coding of
## Sentiment in Political Texts." Political Communication, 29:2, 205-231.

## The citation for this preprocessing script is:
## Luxon, E.  2017. "R Functions for Lexicoder Sentiment Dictionary Pre-Processing."
## Downloadable via http://lexicoder.com/download.html.

#----------------------------------------------------------------------------
#
#	Instructions for Use
#
#----------------------------------------------------------------------------

# You can apply these pre-processing scripts to your corpus as you would any
# other functions in R.

# Note, these scripts require the stringr package, so you must download
# the package prior to use.  You can download the stringr package using the
# following call:
     # install.packages("stringr")

# To load the functions into your workspace, place the LSDprep.R file into your
# working directory, and then use the following call to load the functions into
# your working environment:
     # source(file = "LSDprep_dec2017.R")

# You can use functions on any vector of texts, including texts within a column
# of a data frame.
     # For example:
     # LSDprep1_punc(x)
     # LSDprep1_punc(df$text)

# Note: These functions DO NOT print the output to the screen.  You must either
# save the output into a new variable or overwrite the original vector.  If you
# would like to print the output to the screen, you will need to explicitly tell
# R to do so using print() or ().
     # To save the output:
          # x <- LSDprep1_punc(x)
          # df$text <- LSDprep1_punc(df$text)
     # To print the output:
          # print(LSDprep1_punc(x))
          # (LSDprep1_punc(df$text))

# There are five main pre-processing functions below.  They should typically be
# run in the order in which they are described.  Note that old pre-processing 
# scripts for use with the LSD dealt extensively with punctuation and
# capitalization, but that is no longer the case here, since there are many
# packages for R that remove punctuation and capitalization.

# However, the first two functions here require that punctuation has NOT yet
# been removed, while the last two functions require that SPACES have been
# inserted around all punctuation.

# The third function, below, inserts spaces between text and punctuation.  It
# can be modified to include additional punctuation.

# There are also several optional pre-processing functions that will allow you
# to remove punctuation within some types of tokens that include punctuation,
# such as numbers, acronyms, and abbreviations.  This will prevent the function
# that adds space around punctuation from splitting those elements into multiple
# tokens.

# There is a final optional function that will mark out capitalized words (other
# than the first word in a sentence), so they will NOT be counted when the LSD 
# dictionaries are applied.  As per Young & Soroka (2012), proper nouns, by 
# definition, cannot have sentiment.  Therefore counting sentiment words that 
# coincide with individual's names, company names, etc., will overinflate 
# sentiment results.   The function to mark proper nouns will help address this 
# concern, to some extent.  Though note that it cannot distinguish between a 
# regulat word and a proper noun at the beginning of a sentence (as written,
# words at the beginning of sentences will not be marked off with an underscore,
# even if they are proper nouns).

#### WARNING ####
# Note that these functions make changes to the text - changes that will not
# typically be useful for content analyses other than the estimation of
# sentiment using the LSD.  If users are running several different analyses
# of text, it is likely important to keep one batch that is pre-processed
# using these functions, for LSD specifically; and another batch that is
# not pre-processed using these functions, for all other analyses.  To be
# clear: these are not general-purpose pre-processing scripts, they are
# designed only to improve the dictionary counts from the LSD2015 dictionary.


# The 5 major LSD pre-processing functions are as follows:

# LSDprep_contr: The function replaces a number of contractions that are
# relevant to properly identifying negations with the full negation.  For
# instance, "ain't" is replaced with "am not".  This will improve the
# identification of negations when running the LSD2015_NEG dictionary.  This
# function should be used BEFORE any changes are made to punctuation.

# LSDprep_dict_punct: This function addresses dictionary words that should not
# be included in dictionary counts, and that can be identified in relation to
# surrounding punctuation.  For example, "well" should not be counted as a
# positive word, when it is used at the beginning of a sentence, as so: " Well,
# ".  The function changes this usage to " xwell ".   This function should be
# used BEFORE any changes are made to punctuation.

# LSDprep_punctspace: This function inserts spaces around punctuation marks, to 
# ensure that all instances of phrases in the following two functions will work 
# correctly.  In lieu of this function, you may also run an alternative function
# that simply removes all punctuation from the texts.  However, keep in mind 
# that if you simply remove all the punctuation, you will not be able to use the
# Lexicoder functions that identify colocations within sentences.  Note: this 
# function will not distinguish between punctuation within numbers and other 
# punctuation.  The first two optional pre-processing functions, explained below, are
# intended to address some of these issues.

# LSDprep_negation: This function takes a wide range of phrases that indicate 
# negations, such as "not very" and "not always", and turns them all into just 
# "not", which improves the identification of negations when running the 
# LSD2015_NEG dictionary.  The R code depends on there being spaces around 
# words, therefore this function should be used either AFTER punctuation has
# been removed, OR AFTER spaces have been inserted around punctuation marks.

# LSDprep_dict: This function destroys variations of dictionary words that 
# should not be included in dictionary counts.  For instance, "well" should not 
# be counted as positive word when it appears in the phrase "may very well". 
# This function changes "may very well" to "may very xwell", which prevents 
# "well" from being counted when running the LSD2015 dictionary.  The R code 
# depends on there being spaces around words, therefore this function should be
# used either AFTER punctuation has been removed, OR AFTER spaces have been 
# inserted around punctuation marks.

## The three optional pre-processing functions are as follows:

# remove_punctuation_from_acronyms: This function identifies periods in between
# single capital letters, and removes the punctuation.  For example "U.S.A."
# becomes USA.  It does NOT alter lower case acronyms (i.e. "u.s.a.").  See
# function to "remove_punctuation_from_abbreviations" to remove periods from
# Upper-Case acronyms with spaces (i.e. "U. S. A.").

# remove_punctuation_from_abbreviations: This function removes periods from the
# end of common abbreviations.  For the most part it leaves the abbreviations
# untouched, with a few exceptions (such as replacing "No. 9" with "number 9").
# This function also removes periods after single capital letters, such as for
# middle names or space-separated acronyms.

# mark_proper_nouns: This function marks off words capitalized within the text 
# (but not capitalized words that follow sentence-ending punctuation, such as
# periods). It inserts an underscore after the first letter so that the words
# are not picked up when applying the LSD dictionary.

#----------------------------------------------------------------------------
#
#	Punctuation Dependent Pre-Processing Functions - To apply before modifying punctuation
#
#----------------------------------------------------------------------------

LSDprep_contr <- function(x){
     require(stringr)
     x <- str_replace(x, pattern = "^", replacement = " ")  ##  Adds a space to the beginning of the text. (Ensures function works on first word in the text)
     x <- str_replace(x, pattern = "$", replacement = " ")  ##  Adds a space to the end of the text (Ensures function works on last word in the text)
	x <- str_replace_all(x, pattern = " (A|a)in't ", replacement = " am not ")
	x <- str_replace_all(x, pattern = " (L|l)et's ", replacement = " let us ")
	x <- str_replace_all(x, pattern = " (I|i)t's ", replacement = " it is ") 
	x <- str_replace_all(x, pattern = " (W|w)on't ", replacement = " will not ")
	x <- str_replace_all(x, pattern = " (C|c)an't ", replacement = " can not ")  
	x <- str_replace_all(x, pattern = " (S|s)han't ", replacement = " shall not ")  
	x <- str_replace_all(x, pattern = "n't ", replacement = " not ")  
	x <- str_replace_all(x, pattern = " (C|c)annot", replacement = " can not ")
	x <- str_replace_all(x, pattern = "'d've ", replacement = " would have ")
	x <- str_replace_all(x, pattern = "'d ", replacement = " would ")
	x <- str_replace_all(x, pattern = "'ll ", replacement = " will")
	x <- str_replace_all(x, pattern = "'m ", replacement = " am ")
	x <- str_replace_all(x, pattern = "'ve ", replacement = " have ")
	x <- str_replace_all(x, pattern = "'re ", replacement = " are ")
     x <- str_trim(x, side = "both")  ## This removes the extraneous space added to beginning and end by first two lines
}


LSDprep_dict_punct <- function(x){
          ## All of these text modifications are dependent on punctuation,
          ## so keeping them separate will flag to users that they should
          ## apply this function before applying any functions that modify
          ## punctuation or punctuation-text relationships.
     require(stringr)
     x <- str_replace(x, pattern = "^", replacement = " ")  ##  Adds a space to the beginning of the text. (Ensures function works on first word in the text)
     x <- str_replace(x, pattern = "$", replacement = " ")  ##  Adds a space to the end of the text (Ensures function works on last word in the text)
     x <- str_replace_all(x, pattern = "\\s", replacement = " ") ## This plus the next line collapse spaces between words so that there is no more than one space.   This ensures that spacing errors don't trip up the following patterns.
     x <- str_replace_all(x, pattern = "( )+", replacement = " ") ##
	x <- str_replace_all(x, pattern = " (G|g)ood-(B|b)ye[a-z]+ | (G|g)ood-(B|b)ye ", replacement = " goodbye ")
	x <- str_replace_all(x, pattern = " (G|g)ood (B|b)ye[a-z]+ | (G|g)ood (B|b)ye ", replacement = " goodbye ")
	x <- str_replace_all(x, pattern = " (G|g)ood-", replacement = " good x")
	x <- str_replace_all(x, pattern = " (I|i)ll( - |-| )(A|a)t( - |-| )(E|e)ase ", replacement = " ill at xease ")
	x <- str_replace_all(x, pattern = " (I|i)ll-", replacement = " ill x")
	x <- str_replace_all(x, pattern = "-(L|l)ike ", replacement = " xlike ")
	x <- str_replace_all(x, pattern = "\"( |)(W|w)ell, ", replacement = '" xwell ')
	x <- str_replace_all(x, pattern = "- (W|w)ell, ", replacement = " xwell ")
	x <- str_replace_all(x, pattern = ", (W|w)ell, ", replacement = " xwell ")
	x <- str_replace_all(x, pattern = " (A|a)s (W|w)ell ", replacement = " as xwell ")
	x <- str_replace_all(x, pattern = "\\.( |)\\.( |)\\.( |)\\.( |)(W|w)ell ", replacement = " xwell ")
	x <- str_replace_all(x, pattern = "\\.( |)\\.( |)\\.( |)(W|w)ell ", replacement = " xwell ")
	x <- str_replace_all(x, pattern = "\\. Well,", replacement = ". xWell ")
	x <- str_replace_all(x, pattern = ": (W|w)ell,", replacement = ": xwell ")
	x <- str_replace_all(x, pattern = " (W|w)ell-", replacement = " well x")
	x <- str_replace_all(x, pattern = " (W|w)ell,", replacement = " xwell ")
	x <- str_replace_all(x, pattern = "- (O|o)kay,", replacement = " xokay ")
	x <- str_replace_all(x, pattern = ", (O|o)kay,", replacement = " xokay ")
	x <- str_replace_all(x, pattern = " (O|o)kay,", replacement = " xokay ")
	x <- str_replace_all(x, pattern = "\"( |)(O|o)kay,", replacement = '" xokay ')
	x <- str_replace_all(x, pattern = "\\.( |)\\.( |)\\.( |)\\.( |)(O|o)kay ", replacement = " xokay ")
	x <- str_replace_all(x, pattern = "\\.( |)\\.( |)\\.( |)(O|o)kay ", replacement = " xokay ")
	x <- str_replace_all(x, pattern = "\\. Okay,", replacement = ". xOkay ")
	x <- str_replace_all(x, pattern = ": (O|o)ay,", replacement = ": xokay ")
	x <- str_replace_all(x, pattern = " (O|o)(K|k)", replacement = " okay ")
	x <- str_replace_all(x, pattern = "'( |)(O|o)kay,", replacement = " xokay ")
	x <- str_replace_all(x, pattern = "\"( |)(O|o)kay,", replacement = " xokay ")
	x <- str_replace_all(x, pattern = " Okay,", replacement = " xOkay ")
	x <- str_replace_all(x, pattern = " Okay ", replacement = " xOkay ")
	x <- str_replace_all(x, pattern = ", (T|t)oo ", replacement = " xtoo ")
	x <- str_replace_all(x, pattern = " (T|t)oo( |)/", replacement = " xtoo /")
	x <- str_replace_all(x, pattern = " (T|t)oo,", replacement = " xtoo ")
	x <- str_replace_all(x, pattern = " (T|t)oo\\.", replacement = " xtoo. ")
	x <- str_replace_all(x, pattern = " (T|t)oo\\?", replacement = " xtoo. ")
	x <- str_replace_all(x, pattern = " (T|t)oo:", replacement = " xtoo ")
     x <- str_trim(x, side = "both")  ## This removes the extraneous space added to beginning and end by first two lines
}



#----------------------------------------------------------------------------
#
#	Punctuation Pre-Processing Functions - These functions modify punctuation-text relationships
#
#----------------------------------------------------------------------------

## Functions to remove punctuation from acronyms and abbreviations

remove_punctuation_from_acronyms <- function(x) {
     require(stringr)
     x <- str_replace_all(x, pattern = "([A-Z])\\.([A-Z])\\.([A-Z])\\.([A-Z])\\.([A-Z])\\.([A-Z])\\.", replacement = "\\1\\2\\3\\4\\5\\6")
     x <- str_replace_all(x, pattern = "([A-Z])\\.([A-Z])\\.([A-Z])\\.([A-Z])\\.([A-Z])\\.", replacement = "\\1\\2\\3\\4\\5")
     x <- str_replace_all(x, pattern = "([A-Z])\\.([A-Z])\\.([A-Z])\\.([A-Z])\\.", replacement = "\\1\\2\\3\\4")
     x <- str_replace_all(x, pattern = "([A-Z])\\.([A-Z])\\.([A-Z])\\.", replacement = "\\1\\2\\3")
     x <- str_replace_all(x, pattern = "([A-Z])\\.([A-Z])\\.", replacement = "\\1\\2")
     x <- str_replace_all(x, pattern = "([A-Z])\\.([A-Z]) ", replacement = "\\1\\2 ")
}

remove_punctuation_from_abbreviations <- function(x) {
     require(stringr)
	x <- str_replace_all(x, pattern = " St\\. ", replacement = " St ")
	x <- str_replace_all(x, pattern = " Ste\\. ", replacement = " Ste ")
	x <- str_replace_all(x, pattern = " Rt\\. ", replacement = " Rt ")
	x <- str_replace_all(x, pattern = " (I|i)\\.(| )(E|e)\\. ", replacement = " ie ")
	x <- str_replace_all(x, pattern = " (E|e)\\.(| )(G|g)\\. ", replacement = " eg ")
	x <- str_replace_all(x, pattern = " Mr\\. ", replacement = " Mr ")
	x <- str_replace_all(x, pattern = " Ms\\. ", replacement = " Ms ")
	x <- str_replace_all(x, pattern = " Mrs\\. ", replacement = " Mrs ")
	x <- str_replace_all(x, pattern = " Prof\\. ", replacement = " Prof ")
	x <- str_replace_all(x, pattern = " Gen\\. ", replacement = " Gen ")
	x <- str_replace_all(x, pattern = " Dr\\. ", replacement = " Dr ")
	x <- str_replace_all(x, pattern = " Gov\\. ", replacement = " Gov ")
	x <- str_replace_all(x, pattern = " Pres\\. ", replacement = " Pres ")
	x <- str_replace_all(x, pattern = " Univ\\. ", replacement = " Univ ")
	x <- str_replace_all(x, pattern = " Rep\\. ", replacement = " Rep ")
	x <- str_replace_all(x, pattern = " Sen\\. ", replacement = " Sen ")
	x <- str_replace_all(x, pattern = " Sec\\. ", replacement = " Sec ")
	x <- str_replace_all(x, pattern = " Jud\\. ", replacement = " Jud ")
	x <- str_replace_all(x, pattern = " Inc\\. ", replacement = " Inc ")
	x <- str_replace_all(x, pattern = " Hon\\. ", replacement = " Ho ")
	x <- str_replace_all(x, pattern = " Co\\. ", replacement = " Co ")
	x <- str_replace_all(x, pattern = " Jr\\. ", replacement = " Jr ")
	x <- str_replace_all(x, pattern = " Sr\\. ", replacement = " Jr ")
	x <- str_replace_all(x, pattern = " (P|p)(H|h)\\.(D|d) ", replacement = " PhD ")
	x <- str_replace_all(x, pattern = "(A|a)\\.(| )(M|m)\\. ", replacement = " am ")
	x <- str_replace_all(x, pattern = "(P|p)\\.(| )(M|m)\\. ", replacement = " pm ")
	x <- str_replace_all(x, pattern = "( |\\()Jan\\. ", replacement = "\\1Jan ")
	x <- str_replace_all(x, pattern = "( |\\()Feb\\. ", replacement = "\\1Feb ")
	x <- str_replace_all(x, pattern = "( |\\()Mar\\. ", replacement = "\\1Mar ")
	x <- str_replace_all(x, pattern = "( |\\()Apr\\. ", replacement = "\\1Apr ")
	x <- str_replace_all(x, pattern = "( |\\()Jun\\. ", replacement = "\\1Jun ")
	x <- str_replace_all(x, pattern = "( |\\()Jul\\. ", replacement = "\\1Jul ")
	x <- str_replace_all(x, pattern = "( |\\()Aug\\. ", replacement = "\\1Aug ")
	x <- str_replace_all(x, pattern = "( |\\()Sept\\. ", replacement = "\\1Sept ")
	x <- str_replace_all(x, pattern = "( |\\()Oct\\. ", replacement = "\\1Oct ")
	x <- str_replace_all(x, pattern = "( |\\()Nov\\. ", replacement = "\\1Nov ")
	x <- str_replace_all(x, pattern = "( |\\()Dec\\. ", replacement = "\\1Dec ")
	x <- str_replace_all(x, pattern = " (E|e)\\. (C|c)oli", replacement = " Ecoli")
	x <- str_replace_all(x, pattern = " (No)(\\.)(| )([0-9]+)", replacement = " number \\4")
	x <- str_replace_all(x, pattern = " ([A-Z])(\\.)( )", replacement = " \\1 ")  # Removes period after single letter abbreviations (i.e. middle initials)

}

LSDprep_punctspace <- function(x) {
     require(stringr)
     x <- str_replace_all(x, pattern = ",[^0-9]", replacement = " , ")
     x <- str_replace_all(x, pattern = '"', replacement = ' " ')
     x <- str_replace_all(x, pattern = "([\\?\\!;:\\*,#•■])", replacement = " \\1 ")
     x <- str_replace_all(x, pattern = "-", replacement = " - ")
     x <- str_replace_all(x, pattern = "\\(", replacement = " \\( ")
     x <- str_replace_all(x, pattern = "\\)", replacement = " \\) ")
     x <- str_replace_all(x, pattern = "\\[", replacement = " \\[ ")
     x <- str_replace_all(x, pattern = "\\]", replacement = " \\] ")
     x <- str_replace_all(x, pattern = "\\.", replacement = " . ")
     x <- str_replace_all(x, pattern = "([a-zA-Z]+)(')", replacement = "\\1 \\2")
	x <- str_replace_all(x, pattern = "(')([a-zA-Z]+)", replacement = "\\1 \\2")
	x <- str_replace_all(x, pattern = "\\s", replacement = " ")
     x <- str_replace_all(x, pattern = "( )+", replacement = " ")
}



#----------------------------------------------------------------------------
#
#	Pre-Processing Functions - These functions depend on spaces between words and punctuation
#
#----------------------------------------------------------------------------


LSDprep_negation <- function(x){
     require(stringr)
     x <- str_replace(x, pattern = "^", replacement = " ")
     x <- str_replace(x, pattern = "$", replacement = " ")
     x <- str_replace_all(x, pattern = "\\s", replacement = " ") ## This plus the next line collapse spaces between words so that there is no more than one space.   This ensures that spacing errors don't trip up the following patterns.
     x <- str_replace_all(x, pattern = "( )+", replacement = " ") 
	x <- str_replace_all(x, pattern = " (N|n)obody (B|b)etter ", replacement = " xnobody better ")
	x <- str_replace_all(x, pattern = " (N|n)othing (B|b)etter ", replacement = " xnothing better ")
	x <- str_replace_all(x, pattern = " (N|n)on( - |-| )(C|c)onfidence ", replacement = " non xconfidence ")
	x <- str_replace_all(x, pattern = " (N|n)on( - |-| )(E|e)mergenc[a-z]+ | (N|n)on( - |-| )(E|e)mergency ", replacement = " non xemergency ")
	x <- str_replace_all(x, pattern = " (N|n)on( - |-| )(E|e)ssential[a-z]+ | (N|n)on( - |-| )(E|e)ssential ", replacement = " non xessential ")
	x <- str_replace_all(x, pattern = " (N|n)on( - |-| )(I|i)nvasive ", replacement = " non xinvasive ")
	x <- str_replace_all(x, pattern = " (N|n)on( - |-| )(T|t)oxic ", replacement = " nontoxic ")
	x <- str_replace_all(x, pattern = " (N|n)o( - |-| )(O|o)ne (E|e)lse[a-z]+ | (N|n)o( - |-| )(O|o)ne (E|e)lse ", replacement = " (no_one else) not ")
	x <- str_replace_all(x, pattern = " (N|n)o( - |-| )(O|o)ne ", replacement = " (no_one) not ")
	x <- str_replace_all(x, pattern = " (N|n)o( - |-| )(N|n)o ", replacement = " no_no ")
	x <- str_replace_all(x, pattern = " (N|n)o (K|k)idding ", replacement = " no xkidding ")
	x <- str_replace_all(x, pattern = " (W|w)ell (N|n)o ", replacement = " xwell no ")
	x <- str_replace_all(x, pattern = " (N|n)o ", replacement = " (no) not ")
	x <- str_replace_all(x, pattern = " (N|n)o_no ", replacement = " no no ")
	x <- str_replace_all(x, pattern = " (N|n)on ", replacement = " (non) not ")
	x <- str_replace_all(x, pattern = " (N|n)or ", replacement = " (nor) not ")
	x <- str_replace_all(x, pattern = " (N|n)either ", replacement = " (neither) not ")
	x <- str_replace_all(x, pattern = " (N|n)ever ", replacement = " (never) not ")
	x <- str_replace_all(x, pattern = " \\((N|n)o\\) (N|n)ot ( - |-| |)longer ", replacement = " (no_longer) not ")
	x <- str_replace_all(x, pattern = " (H|h)ardly ", replacement = " (hardly) not ")
	x <- str_replace_all(x, pattern = " (N|n)obody[a-z]+ | (N|n)obody ", replacement = " (nobody) not ")
	x <- str_replace_all(x, pattern = " (N|n)one ", replacement = " (none) not ")
	x <- str_replace_all(x, pattern = " (A|a)void ", replacement = " (avoid) not ")
	x <- str_replace_all(x, pattern = " (A|a)voided ", replacement = " (avoided) not ")
	x <- str_replace_all(x, pattern = " (A|a)voiding ", replacement = " (avoiding) not ")
	x <- str_replace_all(x, pattern = " (A|a)voids ", replacement = " (avoids) not ")
	x <- str_replace_all(x, pattern = " (N|n)othing ", replacement = " (nothing) not ")
	x <- str_replace_all(x, pattern = " (L|l)ess ", replacement = " (less) not ")
	x <- str_replace_all(x, pattern = " (M|m)inimize ", replacement = " (minimize) not ")
	x <- str_replace_all(x, pattern = " (R|r)educe ", replacement = " (reduce) not ")
	x <- str_replace_all(x, pattern = " (W|w)ithdr[a-z]+ ", replacement = " (withdraw) not ")
	x <- str_replace_all(x, pattern = " (L|l)ow ", replacement = " (low) not ")
	x <- str_replace_all(x, pattern = "( )+", replacement = " ") ## Just in case previous lines overly padded spaces between words, this removes extra spaces
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(E|e)nd ", replacement = " low end ")
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(P|p)oint[a-z]+ | \\(low\\) not ( - |-| |)(P|p)oint ", replacement = " low point ")
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(Q|q)uality ", replacement = " low quality ")
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(R|r)ank[a-z]+ | \\(low\\) not ( - |-| |)(R|r)ank ", replacement = " low rank ")
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(R|r)ated ", replacement = " low rated ")
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(R|r)egard ", replacement = " low regard ")
	x <- str_replace_all(x, pattern = " \\(low\\) not ( - |-| |)(E|e)xpectation[a-z]+ | \\(low\\) not ( - |-| |)(E|e)xpectation ", replacement = " low expectation ")
	x <- str_replace_all(x, pattern = " (A|a) (L|l)ittle ", replacement = " a xlittle ")
	x <- str_replace_all(x, pattern = " (A|a)s (L|l)ittle ", replacement = " as xlittle ")
	x <- str_replace_all(x, pattern = " (A|a)t (L|l)ittle ", replacement = " at xlittle ")
	x <- str_replace_all(x, pattern = " (C|c)ute (L|l)ittle ", replacement = " cute xlittle ")
	x <- str_replace_all(x, pattern = " (L|l)ittle (B|b)oy[a-z]+ | (L|l)ittle (B|b)oy ", replacement = " xlittle boy ")
	x <- str_replace_all(x, pattern = " (L|l)ittle girl[a-z]+ | (L|l)ittle girl ", replacement = " xlittle girl ")
	x <- str_replace_all(x, pattern = " (P|p)oor (L|l)ittle (R|r)ich ", replacement = " poor xlittle xrich ")
	x <- str_replace_all(x, pattern = " (L|l)ittle ", replacement = " (little) not ")
	x <- str_replace_all(x, pattern = " (W|w)ithout ", replacement = " (without) not ")
	x <- str_replace_all(x, pattern = "( )+", replacement = " ")
	x <- str_replace_all(x, pattern = " \\(no\\) not( - |-| |)(M|m)an( ' |')s( - |-| )land ", replacement = " no man's land ")
	x <- str_replace_all(x, pattern = " (B|b)reak \\(no\\) not ( - |-| |)bones ", replacement = " break no bones ")
	x <- str_replace_all(x, pattern = " (N|n)ot always ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot appear ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot other ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot way to ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot way we ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot way you ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot a very ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot as a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot as an ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot all are ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot all was ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot all that ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot all of the ", replacement = " not ") 
	x <- str_replace_all(x, pattern = " (N|n)ot actually ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot are there ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot at a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot at all ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot at the ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot at their ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot back to ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be as ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be get[a-z]+ | (N|n)ot be get ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be giv[a-z]+ ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be so ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be able to ", replacement = " not able to ")
	x <- str_replace_all(x, pattern = " (N|n)ot be like ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been an ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been any ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been as ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been so ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been in ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been able to ", replacement = " not able to ")
	x <- str_replace_all(x, pattern = " (N|n)ot been like ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot being a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot being as ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot being so ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot being like ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot being able to ", replacement = " not able to ")
	x <- str_replace_all(x, pattern = " (N|n)ot able to ", replacement = " not able to x")
	x <- str_replace_all(x, pattern = " (N|n)ot can it ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot can be ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot can really ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot cause[a-z]+ for | (N|n)ot cause for ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could the ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could they ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could she ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could he ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could have ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot did he ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot did she ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot did they ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot did the ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot did get ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do they have ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do they ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do the ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do (i|I) ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do as ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do us ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do anything ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does it ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does his ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does her ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does she ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does he ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does the ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot doing a ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot doing as ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot doing anything ", replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot done a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot done as " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot done anything " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot else was " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot even a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot even " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot x(| )ever " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot ever " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot feel[a-z]+ | (N|n)ot feel " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot found a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot found an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot found any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot found the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot found their " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ a | (N|n)ot get a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ an | (N|n)ot get an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ any | (N|n)ot get any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ the | (N|n)ot get the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ enough | (N|n)ot get enough " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ their | (N|n)ot get their " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot giv[a-z]* a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot giv[a-z]+ any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot good " , replacement = " not xgood ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to get | (N|n)ot go to get " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to be a | (N|n)ot go to be a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to be | (N|n)ot go to be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to do | (N|n)ot go to do " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to the | (N|n)ot go to the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to get | (N|n)ot go to get " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to give | (N|n)ot go to give " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to have the | (N|n)ot go to have the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to have | (N|n)ot go to have " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to make a | (N|n)ot go to make a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to make | (N|n)ot go to make " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ to | (N|n)ot go to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ any | (N|n)ot go any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go[a-z]+ as | (N|n)ot go as " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot going " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot got a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot got an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot got any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot got the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot got to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had it so " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had really " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had he " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had it been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had she " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had they " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had there " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot had " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has ever been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has ever " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has it been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has their been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has their " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has really " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has taken " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has yet " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot has " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ as " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ much " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ their " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ they " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ enough " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot hav[a-z]+ " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot his " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot her " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot in the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot in a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot in " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is get[a-z]+ | (N|n)ot is get " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is going " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is more " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is really " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is it an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is there any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is there " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot is " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot its " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot just " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot look[a-z]+ | (N|n)ot look " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot mak[a-z]+ any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot mak[a-z]+ an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot mak[a-z]+ a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot mak[a-z]+ it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot mak[a-z]+ " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot much " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot more " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot mov[a-z]+ " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot nearly as " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot nearly " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of it is " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of it was " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of that " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of them were " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of them " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of these " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of this would " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of this " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of us are " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of us " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of which " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of whom " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot of " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot on " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot our " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot over " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot pull it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot pull " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot quite " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot real " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot really a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot really all " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot really had the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot really had a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot really seen " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot really " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot saw any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot saw a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot seek[a-z]+ | (N|n)ot seek " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot seem[a-z]+ to be | (N|n)ot seem to be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot seem[a-z]+ to | (N|n)ot seem to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot seem[a-z]+ quite | (N|n)ot seem quite " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot seem[a-z]+ | (N|n)ot seem " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot should be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot should ever " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot should have " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot should " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot sign[a-z]+ of any | (N|n)ot sign of any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot sign[a-z]+ of an | (N|n)ot sign of an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot sign[a-z]+ of a | (N|n)ot sign of a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot sign[a-z]+ of | (N|n)ot sign of " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot similar " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot so " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot such " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot tak[a-z]+ a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot tak[a-z]+ " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot than " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot that " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot their " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to be a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to get " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to give " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to have a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to have any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to have been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot to have " , replacement = " not ")
     x <- str_replace_all(x, pattern = "( )+", replacement = " ")
	x <- str_replace_all(x, pattern = " (T|t)he right not to " , replacement = " the right xnot to ")
	x <- str_replace_all(x, pattern = " (T|t)heir right not to " , replacement = " their right xnot to ")
	x <- str_replace_all(x, pattern = " (N|n)ot to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (T|t)he right xnot to " , replacement = " the right not to ")
	x <- str_replace_all(x, pattern = " (T|t)heir right xnot to " , replacement = " their right not to ")
	x <- str_replace_all(x, pattern = " (N|n)ot up to any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot up to " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot too " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot very " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was he " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was she " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was his " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was her " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was there any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was there " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was the " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot was " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot way " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot were there any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot were there " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot were any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot were " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will ever " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will they be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will they " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will it be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot will " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would have been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would ever " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would have " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would say " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would it " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would he " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would she " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would they " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot would " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot yet " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot a " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot an " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot as " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot all " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot any[a-z]+ | (N|n)ot any " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot are " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot at " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot be " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot been " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot become " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot before " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot being " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot can " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot could " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot did " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot do " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot does " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot doing " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot done " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot else " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot far " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot felt " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot found " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot further " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot fully " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot get[a-z]+ | (N|n)ot get " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot giv[a-z]+ " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot go " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot xgood " , replacement = " not good ")
	x <- str_replace_all(x, pattern = " (N|n)ot got " , replacement = " not ")
	x <- str_replace_all(x, pattern = " (N|n)ot [a-z]+ well " , replacement = " not well ")
	x <- str_replace_all(x, pattern = " (N|n)ot [a-z]+ responsib[a-z]+ " , replacement = " not responsible ")
     x <- str_trim(x, side = "both")  ## This removes the extraneous space added to beginning and end by first two lines
}



LSDprep_dict <- function(x){
     require(stringr)
     x <- str_replace(x, pattern = "^", replacement = " ")  ##  Adds a space to the beginning of the text. (Ensures function works on first word in the text)
     x <- str_replace(x, pattern = "$", replacement = " ")  ##  Adds a space to the end of the text (Ensures function works on last word in the text)
     x <- str_replace_all(x, pattern = "\\s", replacement = " ") ## This plus the next line collapse spaces between words so that there is no more than one space.   This ensures that spacing errors don't trip up the following patterns.
     x <- str_replace_all(x, pattern = "( )+", replacement = " ") 
	x <- str_replace_all(x, pattern = " (L|l)ie (d|D)etector " , replacement = " xlie detector ")
	x <- str_replace_all(x, pattern = " (A|a)dvance (p|P)oll[a-z]+ | (A|a)dvance (p|P)oll " , replacement = " xadvance poll ")
	x <- str_replace_all(x, pattern = " (I|i)n (a|A)dvance " , replacement = " in xadvance ")
	x <- str_replace_all(x, pattern = " (A|a)gainst (A|a) (B|b)ack[a-z]+ | (A|a)gainst (A|a) (B|b)ack " , replacement = " xagainst a backdrop ")
	x <- str_replace_all(x, pattern = " (A|a)gainst (T|t)he (B|b)back[a-z]+ | (A|a)gainst (T|t)he (B|b)ack " , replacement = " xagainst the backdrop ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (T|t)hat (A|a)gainst " , replacement = " balance that xagainst ")
	x <- str_replace_all(x, pattern = " (B|b)alan[a-z]+ (T|t)hem (A|a)gainst " , replacement = " balance them xagainst ")
	x <- str_replace_all(x, pattern = " (C|c)ompar[a-z]+ (A|a)gainst " , replacement = " compare xagainst ")
	x <- str_replace_all(x, pattern = " (D|d)efen[a-z]+ (A|a)gainst " , replacement = " defend xagainst ")  
	x <- str_replace_all(x, pattern = " (F|f)ight (B|b)ack (A|a)gainst " , replacement = " fight back xagainst ")
	x <- str_replace_all(x, pattern = " (F|f)or (A|a)nd (A|a)gainst " , replacement = " for and xagainst ")
	x <- str_replace_all(x, pattern = " (F|f)ought (B|b)ack (A|a)gainst " , replacement = " fought back xagainst ")
	x <- str_replace_all(x, pattern = " (G|g)ame is (A|a)gainst " , replacement = " game is xagainst ")
	x <- str_replace_all(x, pattern = " (G|g)ame[a-z]+ (A|a)gainst | (G|g)ame (A|a)gainst " , replacement = " game xagainst ")
	x <- str_replace_all(x, pattern = " (I|i)nformation (A|a)gainst " , replacement = " information xagainst ")
	x <- str_replace_all(x, pattern = " (P|p)lay (A|a)gainst " , replacement = " play xagainst ")
	x <- str_replace_all(x, pattern = " (P|p)rotect[a-z]+ (A|a)gainst | (P|p)rotect (A|a)gainst " , replacement = " protect xagainst ")
	x <- str_replace_all(x, pattern = " (R|r)un[a-z]+ (A|a)gainst | (R|r)un (A|a)gainst " , replacement = " run xagainst ")
	x <- str_replace_all(x, pattern = " (S|s)afeguard (A|a)gainst " , replacement = " safeguard xagainst ")
	x <- str_replace_all(x, pattern = " (S|s)upport (A|a)gainst " , replacement = " support xagainst ")
	x <- str_replace_all(x, pattern = " (U|u)nite (A|a)gainst " , replacement = " unite xagainst ")
	x <- str_replace_all(x, pattern = " (V|v)ictory (A|a)gainst " , replacement = " victory xagainst ")
	x <- str_replace_all(x, pattern = " (W|w)ith (U|u)s (O|o)r (A|a)gainst (U|u)s " , replacement = " with us or xagainst us ")
	x <- str_replace_all(x, pattern = " (N|n)ot (F|f)or (N|n)ot (A|a)gainst " , replacement = " not xfor not xagainst ")
	x <- str_replace_all(x, pattern = " (A|a)nti( - |-| )(s|S)ocial " , replacement = " antisocial ")
	x <- str_replace_all(x, pattern = " (A|a)nti( - |-| )" , replacement = " anti x")
	x <- str_replace_all(x, pattern = " (A|a)wful (L|l)ot " , replacement = " xawful lot ")
	x <- str_replace_all(x, pattern = " (A|a)ccount (B|b)alance[a-z]+ | (A|a)ccount (B|b)alance " , replacement = " account xbalance ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+( - |-| )(B|b)udget[a-z]+ | (B|b)alanc[a-z]+( - |-| )(B|b)udget " , replacement = " xbalance budget ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (I|i)ts (B|b)ooks " , replacement = " xbalance its books ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (I|i)ts (B|b)udget[a-z]+ | (B|b)alanc[a-z]+ (I|i)ts (B|b)udget " , replacement = " xbalance its budget ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (T|t)he (B|b)ooks " , replacement = " xbalance the books ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (T|t)he (B|b)udget[a-z]+ | (B|b)alanc[a-z]+ (T|t)he (B|b)udget " , replacement = " xbalance the budget ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (T|t)heir (B|b)ooks " , replacement = " xbalance their books ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (T|t)heir (B|b)udget[a-z]+ | (B|b)alanc[a-z]+ (T|t)heir (B|b)udget " , replacement = " xbalance their budget ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (D|d)ue " , replacement = " xbalance due ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (O|o)f (P|p)robabilit[a-z]+ " , replacement = " xbalance of probabilit ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (O|o)w[a-z] " , replacement = " xbalance owing ")
	x <- str_replace_all(x, pattern = " (B|b)alanc[a-z]+ (S|s)heet[a-z]+ | (B|b)alance[a-z]+ (S|s)heet " , replacement = " xbalance sheet ")
	x <- str_replace_all(x, pattern = " (C|c)heck[a-z]+( - |-| )(A|a)nd( - |-| )(B|b)alanc[a-z]+ " , replacement = " check and xbalance ")
	x <- str_replace_all(x, pattern = " (D|d)ebit (B|b)alanc[a-z]+ " , replacement = " debit xbalance ")
	x <- str_replace_all(x, pattern = " (F|f)iscal (B|b)alanc[a-z]+ " , replacement = " fiscal xbalance ")
	x <- str_replace_all(x, pattern = " (H|h)ang[a-z]+ (I|i)n (T|t)he (B|b)alance | (H|h)ang (I|i)n the balance " , replacement = " hang in the xbalance ")
	x <- str_replace_all(x, pattern = " (H|h)ung (I|i)n (T|t)he (B|b)alance " , replacement = " hung in the xbalance ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (H|h)er (B|b)alance " , replacement = " lose her xbalance ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (H|h)is (B|b)alance " , replacement = " lose his xbalance ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (M|m)y (B|b)alance " , replacement = " lose my xbalance ")
	x <- str_replace_all(x, pattern = " (O|o)n (B|b)alance " , replacement = " on xbalance ")
	x <- str_replace_all(x, pattern = " (P|p)ower (b|B)alance " , replacement = " power xbalance ")
	x <- str_replace_all(x, pattern = " (S|s)trategic (b|B)alance " , replacement = " strategic xbalance ")
	x <- str_replace_all(x, pattern = " (T|t)rade (b|B)alanc[a-z] " , replacement = " trade xbalance ")
	x <- str_replace_all(x, pattern = " (B|b)arely (A|a)ny " , replacement = " barely ")
	x <- str_replace_all(x, pattern = " (B|b)arely " , replacement = " barely x")
	x <- str_replace_all(x, pattern = " (A|a)t (B|b)est " , replacement = " at xbest ")
	x <- str_replace_all(x, pattern = " (B|b)est (S|s)hot " , replacement = " best xshot ")
	x <- str_replace_all(x, pattern = " (B|b)est (K|k)nown (A|a)s " , replacement = " xbest known as ")
	x <- str_replace_all(x, pattern = " (B|b)etter (K|k)nown (A|a)s " , replacement = " xbetter known as ")
	x <- str_replace_all(x, pattern = " (B|b)etter (O|o)r (N|n)ot " , replacement = " xbetter or not ")
	x <- str_replace_all(x, pattern = " (B|b)etter (P|p)art (O|o)f " , replacement = " xbetter part of ")
	x <- str_replace_all(x, pattern = " (B|b)etter (S|s)hot " , replacement = " better xshot ")
	x <- str_replace_all(x, pattern = " (K|k)now (B|b)etter " , replacement = " know xbetter ")
	x <- str_replace_all(x, pattern = " (P|p)eek( - |-| )(a|A)( - |-| )(b|B)oo " , replacement = " peek a xboo ")
	x <- str_replace_all(x, pattern = " (B|b)reak[a-z]+( - |-| )(T|t)hrough | (B|b)reak( - |-| )(T|t)hrough " , replacement = " breakthrough ")
	x <- str_replace_all(x, pattern = " (B|b)road( - |-| )(M|m)ind[a-z]+ | (B|b)road( - |-| )(M|m)ind " , replacement = " broadminded ")
	x <- str_replace_all(x, pattern = " (S|s)peed (B|b)umps " , replacement = " speed xbumps ")
	x <- str_replace_all(x, pattern = " (C|c)hild( - |-| )(c|C)are " , replacement = " child xcare ")
	x <- str_replace_all(x, pattern = " (D|d)ay( - |-| )(c|C)are " , replacement = " day xcare ")
	x <- str_replace_all(x, pattern = " (F|f)oster( - |-| )(c|C)are " , replacement = " foster xcare ")
	x <- str_replace_all(x, pattern = " (G|g)eriatric( - |-| )(c|C)are " , replacement = " geriatric xcare ")
	x <- str_replace_all(x, pattern = " (H|h)ealth( - |-| )(c|C)are " , replacement = " health xcare ")
	x <- str_replace_all(x, pattern = " (H|h)ome( - |-| )(c|C)are " , replacement = " home xcare ")
	x <- str_replace_all(x, pattern = " (I|i)ntensive( - |-| )(c|C)are " , replacement = " intensive xcare ")
	x <- str_replace_all(x, pattern = " (L|l)ongterm( - |-| )(c|C)are " , replacement = " longterm xcare ")
	x <- str_replace_all(x, pattern = " (M|m)edical( - |-| )(c|C)are " , replacement = " medical xcare ")
	x <- str_replace_all(x, pattern = " (P|p)alliative( - |-| )(c|C)are " , replacement = " palliative xcare ")
	x <- str_replace_all(x, pattern = " (P|p)atient( - |-| )(c|C)are " , replacement = " patient xcare ")
	x <- str_replace_all(x, pattern = " (P|p)rivate( - |-| )(c|C)are " , replacement = " private xcare ")
	x <- str_replace_all(x, pattern = " (C|c)eremonial (d|D)agger[a-z]+ | (C|c)eremonial (d|D)agger " , replacement = " xceremonial dagger ")
	x <- str_replace_all(x, pattern = " (C|c)ivil( - |-| )(a|A)ction " , replacement = " xcivil action ")
	x <- str_replace_all(x, pattern = " (C|c)ivil (s|S)uit " , replacement = " xcivil suit ")
	x <- str_replace_all(x, pattern = " (C|c)ombat (t|T)roops " , replacement = " xcombat troops ")
	x <- str_replace_all(x, pattern = " (C|c)onfidence (m|M)otion " , replacement = " xconfidence motion ")
	x <- str_replace_all(x, pattern = " (C|c)onsumer (c|C)onfidence " , replacement = " consumer xconfidence ")
	x <- str_replace_all(x, pattern = " (M|m)atter[a-z]+( - |-| )(O|o)f( - |-| )(c|C)onfidence | (M|m)atter( - |-| )(O|o)of( - |-| )(c|C)onfidence " , replacement = " matter of xconfidence ")
	x <- str_replace_all(x, pattern = " (V|v)ote[a-z]+( - |-| )(O|o)f( - |-| )(c|C)onfidence | (V|v)ote( - |-| )(O|o)f( - |-| )(c|C)onfidence " , replacement = " vote of xconfidence ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (c|C)onfidence " , replacement = " lose xconfidence ")
	x <- str_replace_all(x, pattern = " (N|n)ot (C|c)onfirm (N|n)ot (D|d)eny " , replacement = " not xconfirm not xdeny ")
	x <- str_replace_all(x, pattern = " (G|g)uilty (C|c)onscience " , replacement = " guilty xconscience ")
	x <- str_replace_all(x, pattern = " (A|a)ge (O|o)f (c|C)onsent " , replacement = " age of xconsent ")
	x <- str_replace_all(x, pattern = " (C|c)onsent (f|F)orm[a-z]+ | (C|c)onsent (f|F)orm " , replacement = " xconsent form ")
	x <- str_replace_all(x, pattern = " (O|o)btain[a-z]+ (C|c)onsent | (O|o)btain (C|c)onsent " , replacement = " obtain xconsent ")
	x <- str_replace_all(x, pattern = " (S|s)exual (C|c)onsent[a-z]+ | (S|s)exual (C|c)onsent " , replacement = " sexual xconsent ")
	x <- str_replace_all(x, pattern = " (C|c)rawl (S|s)pace " , replacement = " xcrawl space ")
	x <- str_replace_all(x, pattern = " (P|p)ub (C|c)rawl[a-z]+ | (P|p)ub (C|c)rawl " , replacement = " pub xcrawl ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (C|c)redibility " , replacement = " lose xcredibility ")
	x <- str_replace_all(x, pattern = " (C|c)redit (c|C)ard[a-z]+ | (C|c)redit (c|C)ard " , replacement = " xcredit card ")
	x <- str_replace_all(x, pattern = " (E|e)mployment (c|C)redit[a-z]+ | (E|e)mployment (c|C)redit " , replacement = " employment xcredit ")
	x <- str_replace_all(x, pattern = " (GST|gst) credit[a-z]+ | (GST|gst) (c|C)redit " , replacement = " GST xcredit ")
	x <- str_replace_all(x, pattern = " (HST|hst) credit[a-z]+ | (HST|hst) (c|C)redit " , replacement = " HST xcredit ")
	x <- str_replace_all(x, pattern = " (L|l)ine[a-z]+ (O|o)f (c|C)redit[a-z]+ | (L|l)ine (O|o)f (c|C)redit " , replacement = " line of xcredit ")
	x <- str_replace_all(x, pattern = " (T|t)ax (c|C)redit[a-z]+ | (T|t)ax (c|C)redit " , replacement = " tax xcredit ")
	x <- str_replace_all(x, pattern = " (C|c)ross[a-z]+ [a-zA-Z]+ (L|l)ine | (C|c)ross [a-zA-Z]+ (L|l)ine " , replacement = " cross the line ") 
	x <- str_replace_all(x, pattern = " (C|c)rown (p|P)rosecutor " , replacement = " xcrown prosecutor ")
	x <- str_replace_all(x, pattern = " (B|b)reak (D|d)own (C|c)rude " , replacement = " break down xcrude ")
	x <- str_replace_all(x, pattern = " (C|c)rude (o|O)il[a-z]+ | (C|c)rude (o|O)il " , replacement = " xcrude oil ")
	x <- str_replace_all(x, pattern = " (C|c)rystal (m|M)eth[a-z]+ | (C|c)rystal (m|M)eth " , replacement = " xcrystal meth ")
	x <- str_replace_all(x, pattern = " (I|i)nformation (A|a)gainst[a-z]+ | (I|i)nformation (A|a)gainst " , replacement = " information xagainst ")
	x <- str_replace_all(x, pattern = " (W|w)hole (D|d)amn " , replacement = " xwhole damn ")
	x <- str_replace_all(x, pattern = " (W|w)hole (D|d)arn " , replacement = " xwhole darn ")
	x <- str_replace_all(x, pattern = " (P|p)retty (D|d)arn " , replacement = " xpretty darn ")
	x <- str_replace_all(x, pattern = " (P|p)retty (D|d)amn " , replacement = " xpretty damn ")
	x <- str_replace_all(x, pattern = " (D|d)ead (h|H)eat " , replacement = " xdead heat ")
	x <- str_replace_all(x, pattern = " (P|p)ublic (d|D)efender[a-z]+ | (P|p)ublic (d|D)efender " , replacement = " public xdefender ")
	x <- str_replace_all(x, pattern = " (D|d)emon (W|w)orship " , replacement = " demon xworship ")
	x <- str_replace_all(x, pattern = " (B|b)lue (d|D)evil[a-z]+ | (B|b)lue (d|D)evil " , replacement = " blue xdevil ")
	x <- str_replace_all(x, pattern = " (T|t)ax (E|e)liminat[a-z]+ " , replacement = " tax xelimination ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (c|C)rew[a-z]+ | (E|e)mergency (c|C)rew " , replacement = " xemergency crew ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (d|D)epartment[a-z]+ | (E|e)mergency (d|D)epartment " , replacement = " xemergency department ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (d|D)octor[a-z]+ | (E|e)mergency (d|D)octor " , replacement = " xemergency doctor ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (m|M)anagement " , replacement = " xemergency management ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (p|P)ersonnel " , replacement = " xemergency personnel ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (p|P)hysician[a-z]+ | (E|e)mergency (p|P)hysician " , replacement = " xemergency physician ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (p|P)lan[a-z]+ | (E|e)mergency (p|P)lan " , replacement = " xemergency plan ")
	x <- str_replace_all(x, pattern = " (E|e)mergency( - |-| )(p|P)reparedness " , replacement = " xemergency preparedness ")
	x <- str_replace_all(x, pattern = " (E|e)mergency( - |-| )(r|R)espon[a-z]+ " , replacement = " xemergency respon ")
	x <- str_replace_all(x, pattern = " (E|e)mergency( - |-| )(r|R)oom[a-z]+ | (E|e)mergency (r|R)oom " , replacement = " xemergency room ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (s|S)ervice[a-z]+ | (E|e)mergency (s|S)ervice " , replacement = " xemergency service ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (w|W)ard[a-z]+ | (E|e)mergency (w|W)ard " , replacement = " xemergency ward ")
	x <- str_replace_all(x, pattern = " (E|e)mergency (w|W)orker[a-z]+ | (E|e)mergency (w|W)orker " , replacement = " xemergency worker ")
	x <- str_replace_all(x, pattern = " (E|e)nrich[a-z]+ (M|m)achines | (E|e)nrich (M|m)achines " , replacement = " xenrich machines ")
	x <- str_replace_all(x, pattern = " (E|e)nrich[a-z]+ (O|o)f (U|u)ranium | (E|e)nrich (O|o)f (U|u)ranium " , replacement = " xenrich of uranium ")
	x <- str_replace_all(x, pattern = " (E|e)nrich[a-z]+ (p|P)lant[a-z]+ | (E|e)nrich (p|P)lant " , replacement = " xenrich plant ")
	x <- str_replace_all(x, pattern = " (E|e)nrich[a-z]+ (U|u)ranium | (E|e)nrich (U|u)ranium " , replacement = " xenrich uranium ")
	x <- str_replace_all(x, pattern = " (E|e)nrich[a-z]+ (W|w)hite (F|f)lour | (E|e)nrich (W|w)hite (F|f)lour " , replacement = " xenrich white flour ")
	x <- str_replace_all(x, pattern = " (N|n)uclear( - |-| )(E|e)nrich[a-z]+ | (N|n)uclear( - |-| )(E|e)nrich " , replacement = " nuclear xenrich ")
	x <- str_replace_all(x, pattern = " (U|u)ranium( - |-| )(E|e)nrich[a-z]+ | (U|u)ranium( - |-| )(E|e)nrich " , replacement = " uranium xenrich ")
	x <- str_replace_all(x, pattern = " (E|e)nrichment (P|p)rogram[a-z]+ | (E|e)nrichment (P|p)rogram " , replacement = " xenrichment program ")
	x <- str_replace_all(x, pattern = " (A|a)dult( - |-| )(e|E)ntertainment " , replacement = " adult xentertainment ")
	x <- str_replace_all(x, pattern = " (E|e)ntertainment (i|I)ndustr[a-z]+ " , replacement = " xentertainment industry ")
	x <- str_replace_all(x, pattern = " (E|e)ntertainment (l|L)awyer " , replacement = " xentertainment lawyer ")
	x <- str_replace_all(x, pattern = " (E|e)ssential( - |-| )(f|F)atty( - |-| )(a|A)cid[a-z]+ | (E|e)ssential( - |-| )(f|F)atty( - |-| )(a|A)cid " , replacement = " xessential fatty acid ")
	x <- str_replace_all(x, pattern = " (E|e)ssential (S|s)ervice[a-z]+ | (E|e)ssential (S|s)ervice " , replacement = " xessential service ")
	x <- str_replace_all(x, pattern = " (E|e)ssential (S|s)urger[a-z]+ " , replacement = " xessential surger ")
	x <- str_replace_all(x, pattern = " (N|n)ot (E|e)ssential " , replacement = " not xessential ")
	x <- str_replace_all(x, pattern = " (P|p)oor (S|s)elf (E|e)steem " , replacement = " poor self xesteem ")
	x <- str_replace_all(x, pattern = " (E|e)xcellency " , replacement = " xexcellency ")
	x <- str_replace_all(x, pattern = " (L|l)ife( - |-| )(E|e)xpectanc[a-z]+ " , replacement = " life xexpectancy ")
	x <- str_replace_all(x, pattern = " (E|e)xtreme( - |-| )(A|a)dventur[a-z]+ " , replacement = " xextreme adventure ")
	x <- str_replace_all(x, pattern = " (F|f)ail[a-z]+ (T|t)o | (F|f)ail (T|t)o " , replacement = " fail to x")
	x <- str_replace_all(x, pattern = " (F|f)ail[a-z]+ (E|e)ffort[a-z]+ | (F|f)ail (E|e)ffort " , replacement = " failed xeffort ")
	x <- str_replace_all(x, pattern = " (B|b)ook (F|f)air[a-z]+ | (B|b)ook (F|f)air " , replacement = " book xfair ")
	x <- str_replace_all(x, pattern = " (F|f)air (A|a)mount[a-z]+ | (F|f)air (A|a)mount " , replacement = " xfair amount ")
	x <- str_replace_all(x, pattern = " (F|f)air (B|b)it[a-z]+ | (F|f)air (B|b)it " , replacement = " xfair bit ")
	x <- str_replace_all(x, pattern = " (F|f)air (C|c)hance[a-z]+ | (F|f)air (C|c)hance " , replacement = " xfair chance ")
	x <- str_replace_all(x, pattern = " (F|f)air (N|n)umber[a-z]+ | (F|f)air (N|n)umber " , replacement = " xfair number ")
	x <- str_replace_all(x, pattern = " (F|f)air (T|t)o (S|s)ay " , replacement = " xfair to say ")
	x <- str_replace_all(x, pattern = " (F|f)air( - |-| )(T|t)rade " , replacement = " xfair trade ")
	x <- str_replace_all(x, pattern = " (S|s)cience( - |-| )(F|f)air[a-z]+ | (S|s)cience( - |-| )(F|f)air " , replacement = " science xfair ")
	x <- str_replace_all(x, pattern = " (T|t)he (F|f)air " , replacement = " the xfair ")
	x <- str_replace_all(x, pattern = " (W|w)orld[a-z]+ (F|f)air | (W|w)orld (F|f)air " , replacement = " world xfair ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (F|f)aith " , replacement = " lose xfaith ")
	x <- str_replace_all(x, pattern = " (F|f)alse (T|t)eeth " , replacement = " xfalse teeth ")
	x <- str_replace_all(x, pattern = " (F|f)lip( - |-| )(T|t)op " , replacement = " xflip top ")
	x <- str_replace_all(x, pattern = " (F|f)loppy (D|d)isk[a-z]+ | (F|f)loppy (D|d)isk " , replacement = " xfloppy disk ")
	x <- str_replace_all(x, pattern = " (A|a)luminum( - |-| )(F|f)oil " , replacement = " aluminum xfoil ")
	x <- str_replace_all(x, pattern = " (G|g)old( - |-| )(F|f)oil " , replacement = " gold xfoil ")
	x <- str_replace_all(x, pattern = " (T|t)he (F|f)oil " , replacement = " the xfoil ")
	x <- str_replace_all(x, pattern = " (T|t)in( - |-| )(F|f)oil " , replacement = " tin xfoil ")
	x <- str_replace_all(x, pattern = " (C|c)arry (F|f)orward " , replacement = " carry xforward ")
	x <- str_replace_all(x, pattern = " (F|f)ast (F|f)orward[a-z]+ | (F|f)ast (F|f)orward " , replacement = " fast xforward ")
	x <- str_replace_all(x, pattern = " (F|f)orward( - |-| )(A|a)rtillery " , replacement = " xforward artillery ")
	x <- str_replace_all(x, pattern = " (F|f)orward (B|b)ase[a-z]+ | (F|f)orward (B|b)ase " , replacement = " xforward base ")
	x <- str_replace_all(x, pattern = " (F|f)orward( - |-| )(O|o)perat[a-z]+ " , replacement = " xforward operat ")
	x <- str_replace_all(x, pattern = " (L|l)ean[a-z]+ (F|f)orward | (L|l)ean (F|f)orward " , replacement = " lean xforward ")
	x <- str_replace_all(x, pattern = " (T|t)o (F|f)orward " , replacement = " to xforward ")
	x <- str_replace_all(x, pattern = " (F|f)oster( - |-| )(C|c)hild[a-z]+ | (F|f)oster (C|c)hild " , replacement = " xfoster child ")
	x <- str_replace_all(x, pattern = " (F|f)oster( - |-| )(H|h)ome[a-z]+ | (F|f)oster( - |-| )(H|h)ome " , replacement = " xfoster home ")
	x <- str_replace_all(x, pattern = " (F|f)oster (M|m)other[a-z]+ | (F|f)oster (M|m)other " , replacement = " xfoster mother ")
	x <- str_replace_all(x, pattern = " (F|f)oster (P|p)arent[a-z]+ | (F|f)oster (P|p)arent " , replacement = " xfoster parent ")
	x <- str_replace_all(x, pattern = " (F|f)ree( - |-| )(M|m)arket[a-z]+ | (F|f)ree( - |-| )(M|m)arket " , replacement = " xfree market ")
	x <- str_replace_all(x, pattern = " (F|f)ree( - |-| )(T|t)rade " , replacement = " xfree trade ")
	x <- str_replace_all(x, pattern = " (F|f)ree (V|v)ote[a-z]+ | (F|f)ree (V|v)ote " , replacement = " xfree vote ")
	x <- str_replace_all(x, pattern = " (T|t)ax( - |-| )(F|f)ree " , replacement = " tax xfree ")
	x <- str_replace_all(x, pattern = " (F|f)riendly( - |-| )(F|f)ire " , replacement = " xfriendly fire ")
	x <- str_replace_all(x, pattern = " (G|g)old (S|s)tock[a-z]+ | (G|g)old (S|s)tock " , replacement = " xgold stocks ")
	x <- str_replace_all(x, pattern = " (G|g)old (T|t)eeth " , replacement = " xgold teeth ")
	x <- str_replace_all(x, pattern = " (G|g)olden (R|r)etriever[a-z]+ | (G|g)olden (R|r)etriever " , replacement = " xgolden retriever ")
	x <- str_replace_all(x, pattern = " (A|a) (G|g)ood ([0-9]+)" , replacement = " a xgood \\3 ")
	x <- str_replace_all(x, pattern = " (A|a)ny (G|g)ood " , replacement = " any xgood ")
	x <- str_replace_all(x, pattern = " (B|b)aked( - |-| )(G|g)ood " , replacement = " baked xgood ")
	x <- str_replace_all(x, pattern = " (F|f)or (G|g)ood " , replacement = " for xgood ")
	x <- str_replace_all(x, pattern = " (G|g)ood (C|c)hance " , replacement = " xgood chance ")
	x <- str_replace_all(x, pattern = " (G|g)ood (G|g)rief " , replacement = " xgood grief ")
	x <- str_replace_all(x, pattern = " (G|g)ood (S|s)hot " , replacement = " good xshot ")
	x <- str_replace_all(x, pattern = " (M|m)ore (H|h)arm (T|t)han (G|g)ood " , replacement = " more harm than xgood ")
	x <- str_replace_all(x, pattern = " (O|o)h (M|m)y (G|g)oodness " , replacement = " oh my xgoodness ")
	x <- str_replace_all(x, pattern = " (F|f)all (F|f)rom (G|g)race " , replacement = " fall from xgrace ")
	x <- str_replace_all(x, pattern = " ([0-9]+) (G|g)rand " , replacement = " \\1 xgrand ")
	x <- str_replace_all(x, pattern = " (G|g)rand( - |-| )(j|J)ury " , replacement = " xgrand jury ")
	x <- str_replace_all(x, pattern = " (G|g)rand( - |-| )(t|T)heft " , replacement = " xgrand theft ")
	x <- str_replace_all(x, pattern = " (G|g)rand (T|t)otal " , replacement = " xgrand total ")
	x <- str_replace_all(x, pattern = " (G|g)ravel " , replacement = " xgravel ")
	x <- str_replace_all(x, pattern = " (A|a)llah (I|i)s (G|g)reat " , replacement = " allah is xgreat ")
	x <- str_replace_all(x, pattern = " (G|g)od (I|i)s (G|g)reat " , replacement = " god is xgreat ")
	x <- str_replace_all(x, pattern = " (G|g)reat (A|a)mount[a-z]+ | (G|g)reat (A|a)mount " , replacement = " xgreat amount ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(a|A)unt[a-z]+ | (G|g)reat( - |-| )(a|A)unt " , replacement = " xgreat aunt ")
	x <- str_replace_all(x, pattern = " (G|g)reat (B|b)ig " , replacement = " xgreat big ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)anger " , replacement = " xgreat danger ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)eal[a-z]+ | (G|g)reat deal " , replacement = " xgreat deal ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)egree[a-z]+ | (G|g)reat degree " , replacement = " xgreat degree ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)ifficulty " , replacement = " xgreat difficulty ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)isappointment " , replacement = " xgreat disappointment ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)isservice " , replacement = " xgreat disservice ")
	x <- str_replace_all(x, pattern = " (G|g)reat (D|d)ivide[a-z]+ | (G|g)reat (D|d)ivide " , replacement = " xgreat divide ")
	x <- str_replace_all(x, pattern = " (G|g)reat (E|e)scape[a-z]+ | (G|g)reat (E|e)scape " , replacement = " xgreat escape ")
	x <- str_replace_all(x, pattern = " (G|g)reat (E|e)vil[a-z]+ | (G|g)reat (E|e)vil " , replacement = " xgreat evil ")
	x <- str_replace_all(x, pattern = " (G|g)reat (F|f)ailure[a-z]+ | (G|g)reat (F|f)ailure " , replacement = " xgreat failure ")
	x <- str_replace_all(x, pattern = " (G|g)reat (F|f)ear[a-z]+ | (G|g)reat (F|f)ear " , replacement = " xgreat fear ")
	x <- str_replace_all(x, pattern = " (G|g)reat (G|g)amble[a-z]+ | (G|g)reat (G|g)amble " , replacement = " xgreat gamble ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)randchild[a-z]+ | (G|g)reat( - |-| )(g|G)randchild " , replacement = " xgreat grandchild ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)randdaughter[a-z]+ | (G|g)reat( - |-| )(g|G)randdaughter " , replacement = " xgreat granddaughter ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)randfather[a-z]+ | (G|g)reat( - |-| )(g|G)randfather " , replacement = " xgreat grandfather ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)randmother[a-z]+ | (G|g)reat( - |-| )(g|G)randmother " , replacement = " xgreat grandmother ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)randson[a-z]+ | (G|g)reat( - |-| )(g|G)randson " , replacement = " xgreat grandson ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)reat( - |-| )(a|A)unt[a-z]+ | (G|g)reat( - |-| )(g|G)reat( - |-| )(a|A)unt " , replacement = " xgreat xgreat aunt ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)reat( - |-| )(g|G)rand[a-z]+ | (G|g)reat( - |-| )(g|G)reat( - |-| )(g|G)rand " , replacement = " xgreat xgreat grand ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(g|G)reat( - |-| )(u|U)ncle[a-z]+ | (G|g)reat( - |-| )(g|G)reat( - |-| )(u|U)ncle " , replacement = " xgreat xgreat uncle ")
	x <- str_replace_all(x, pattern = " (G|g)reat (H|h)arm[a-z]+ | (G|g)reat (H|h)arm " , replacement = " xgreat harm ")
	x <- str_replace_all(x, pattern = " (G|g)reat (L|l)oss[a-z]+ | (G|g)reat (L|l)oss " , replacement = " xgreat loss ")
	x <- str_replace_all(x, pattern = " (G|g)reat (O|o)ffence[a-z]+ | (G|g)reat (O|o)ffence " , replacement = " xgreat offence ")
	x <- str_replace_all(x, pattern = " (G|g)reat (P|p)ains " , replacement = " xgreat pains ")
	x <- str_replace_all(x, pattern = " (G|g)reat (P|p)aradox[a-z]+ | (G|g)reat (P|p)aradox " , replacement = " xgreat paradox ")
	x <- str_replace_all(x, pattern = " (G|g)reat (R|r)isk[a-z]+ | (G|g)reat (R|r)isk " , replacement = " xgreat risk ")
	x <- str_replace_all(x, pattern = " (G|g)reat (S|s)acrific[a-z]+ " , replacement = " xgreat sacrifice ")
	x <- str_replace_all(x, pattern = " (G|g)reat (S|s)adness " , replacement = " xgreat sadness ")
	x <- str_replace_all(x, pattern = " (G|g)reat( - |-| )(u|U)ncle[a-z]+ | (G|g)reat( - |-| )(u|U)ncle " , replacement = " xgreat uncle ")
	x <- str_replace_all(x, pattern = " (G|g)reat (V|v)illain[a-z]+ | (G|g)reat (V|v)illain " , replacement = " xgreat villain ")
	x <- str_replace_all(x, pattern = " (G|g)reeting( - |-| )(C|c)ard[a-z]+ | (G|g)reeting( - |-| )(C|c)ard " , replacement = " xgreeting card ")
	x <- str_replace_all(x, pattern = " (F|f)emale (G|g)rizzly " , replacement = " female xgrizzly ")
	x <- str_replace_all(x, pattern = " (G|g)rizzly (B|b)ear[a-z]+ | (G|g)rizzly (B|b)ear " , replacement = " xgrizzly bear ")
	x <- str_replace_all(x, pattern = " (G|g)rizzly (H|h)abitat " , replacement = " xgrizzly habitat ")
	x <- str_replace_all(x, pattern = " (G|g)rizzly (T|t)erritory " , replacement = " xgrizzly territory ")
	x <- str_replace_all(x, pattern = " (M|m)ale (G|g)rizzly " , replacement = " male xgrizzly ")
	x <- str_replace_all(x, pattern = " (G|g)ross( - |-| )(d|D)omestic( - |-| )(p|P)roduct " , replacement = " xgross domestic product ")
	x <- str_replace_all(x, pattern = " (G|g)ross( - |-| )(R|r)evenue[a-z]+ | (G|g)ross( - |-| )(R|r)evenue " , replacement = " xgross revenue ")
	x <- str_replace_all(x, pattern = " (G|g)ross( - |-| )(T|t)on[a-z]+ | (G|g)ross( - |-| )(T|t)on " , replacement = " xgross ton ")
	x <- str_replace_all(x, pattern = " (G|g)ross( - |-| )(W|w)eight[a-z]+ | (G|g)ross( - |-| )(W|w)eight " , replacement = " xgross weight ")
	x <- str_replace_all(x, pattern = " (H|h)ang[a-z]+ (B|b)y (A|a) (T|t)hread | (H|h)ang (B|b)y (A|a) (T|t)hread " , replacement = " hang by a thread ") 
	x <- str_replace_all(x, pattern = " (H|h)ard (D|d)rive[a-z]+ | (H|h)ard (D|d)rive " , replacement = " xhard drive ")
	x <- str_replace_all(x, pattern = " (L|l)ove( - |-| )(H|h)ate " , replacement = " xlove xhate ")
	x <- str_replace_all(x, pattern = " (H|h)igh[a-z]+( - |-| )(P|p)oint[a-z]+ | (H|h)igh( - |-| )(P|p)oint " , replacement = " high point ") 
	x <- str_replace_all(x, pattern = " (H|h)igh[a-z]+( - |-| )(R|r)ank[a-z]+ | (H|h)igh( - |-| )(R|r)ank " , replacement = " high rank ") 
	x <- str_replace_all(x, pattern = " (H|h)igh[a-z]+( - |-| )(R|r)egard | (H|h)igh( - |-| )(R|r)egard " , replacement = " high regard ") 
	x <- str_replace_all(x, pattern = " (H|h)igh[a-z]+( - |-| )(E|e)xpectation[a-z]+ | (H|h)igh( - |-| )(E|e)xpectation " , replacement = " high expectation ") 
	x <- str_replace_all(x, pattern = " (H|h)onor( - |-| )(g|G)uard[a-z]+ | (H|h)onor( - |-| )(g|G)uard " , replacement = " xhonor guard ")
	x <- str_replace_all(x, pattern = " (H|h)onour( - |-| )(g|G)uard[a-z]+ | (H|h)onour( - |-| )(g|G)uard " , replacement = " xhonour guard ")
	x <- str_replace_all(x, pattern = " (Y|y)our (h|H)onor " , replacement = " your xhonor ")
	x <- str_replace_all(x, pattern = " (Y|y)our (h|H)onour " , replacement = " your xhonour ")
	x <- str_replace_all(x, pattern = " (B|b)uried (A|a)ll (H|h)ope " , replacement = " buried all xhope ")
	x <- str_replace_all(x, pattern = " (B|b)ury (A|a)ll (H|h)ope " , replacement = " bury all xhope ")
	x <- str_replace_all(x, pattern = " (D|d)eath (O|o)f (H|h)ope " , replacement = " death of xhope ")
	x <- str_replace_all(x, pattern = " (D|d)evoid (O|o)f (H|h)ope " , replacement = " devoid of xhope ")
	x <- str_replace_all(x, pattern = " (F|f)alse (H|h)ope[a-z]+ | (F|f)alse (H|h)ope " , replacement = " false xhope ")
	x <- str_replace_all(x, pattern = " (H|h)ope (F|f)ades " , replacement = " xhope fades ")
	x <- str_replace_all(x, pattern = " (H|h)ope (F|f)ading " , replacement = " xhope fading ")
	x <- str_replace_all(x, pattern = " (H|h)ope (N|n)ot " , replacement = " xhope not ")
	x <- str_replace_all(x, pattern = " (H|h)ope (S|s)aid " , replacement = " xhope said ")
	x <- str_replace_all(x, pattern = " (H|h)ope (W|w)as (A|a)bandoned " , replacement = " xhope was abandoned ")
	x <- str_replace_all(x, pattern = " (H|h)ope (W|w)as (D|d)ashed " , replacement = " xhope was dashed ")
	x <- str_replace_all(x, pattern = " (H|h)ope (W|w)as (R|r)unning (O|o)ut " , replacement = " xhope was running out ")
	x <- str_replace_all(x, pattern = " (H|h)ope (W|w)as (S|s)carce " , replacement = " xhope was scarce ")
	x <- str_replace_all(x, pattern = " (K|k)ill[a-z]+ (A|a)ll (H|h)ope | (K|k)ill (A|a)ll (H|h)ope " , replacement = " kill all xhope ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (A|a)ll (H|h)ope " , replacement = " lose all xhope ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (H|h)ope[a-z]+ " , replacement = " lose xhope ")
	x <- str_replace_all(x, pattern = " (S|s)cant (H|h)ope[a-z]+ | (S|s)cant (H|h)ope " , replacement = " scant xhope ")
	x <- str_replace_all(x, pattern = " (F|f)aint (H|h)ope (C|c)lause " , replacement = " xfaint xhope clause ")
	x <- str_replace_all(x, pattern = " (F|f)aint (H|h)ope[a-z]+ | (F|f)aint (H|h)ope " , replacement = " faint xhope ")
	x <- str_replace_all(x, pattern = " (O|o)ptical (I|i)llusion[a-z]+ | (O|o)ptical (I|i)llusion " , replacement = " optical xillusion ")
	x <- str_replace_all(x, pattern = " (I|i)mpossible (T|t)o " , replacement = " impossible to x")
	x <- str_replace_all(x, pattern = " (T|t)ax (i|I)ncentive[a-z]+ | (T|t)ax (i|I)ncentive " , replacement = " tax xincentive ")
	x <- str_replace_all(x, pattern = " (C|c)ounter( - |-| )(i|I)nsurgenc[a-z]+ " , replacement = " counter xinsurgency ")
	x <- str_replace_all(x, pattern = " (A|a)nalyze (i|I)ntelligence " , replacement = " analyze xintelligence ")
	x <- str_replace_all(x, pattern = " (A|a)rtificial( - |-| )(i|I)ntelligence " , replacement = " xartificial xintelligence ")
	x <- str_replace_all(x, pattern = " (B|b)ritish( - |-| )(i|I)ntelligence " , replacement = " british xintelligence ")
	x <- str_replace_all(x, pattern = " (C|c)anadian( - |-| )(i|I)ntelligence " , replacement = " canadian xintelligence ")
	x <- str_replace_all(x, pattern = " (C|c)ounter( - |-| )(i|I)ntelligence " , replacement = " counter xintelligence ")
	x <- str_replace_all(x, pattern = " (C|c)riminal( - |-| )(i|I)ntelligence " , replacement = " xcriminal xintelligence ")
	x <- str_replace_all(x, pattern = " (D|d)efence( - |-| )(i|I)ntelligence " , replacement = " defence xintelligence ")
	x <- str_replace_all(x, pattern = " (D|d)efense( - |-| )(i|I)ntelligence " , replacement = " defense xintelligence ")
	x <- str_replace_all(x, pattern = " (D|d)omestic( - |-| )(i|I)ntelligence " , replacement = " domestic xintelligence ")
	x <- str_replace_all(x, pattern = " (F|f)oreign( - |-| )(i|I)ntelligence " , replacement = " foreign xintelligence ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence( - |-| )(a|A)gen[a-z] " , replacement = " xintelligence agency ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence( - |-| )(a|A)ll[a-z]+ " , replacement = " xintelligence ally ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence( - |-| )(a|A)naly[a-z]+ " , replacement = " xintelligence analysis ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (c|C)hief[a-z]+ | (I|i)ntelligence (c|C)hief " , replacement = " xintelligence chief ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (d|D)ocument[a-z]+ | (I|i)ntelligence (d|D)ocument " , replacement = " xintelligence document ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (e|E)xpert[a-z]+ | (I|i)ntelligence (e|E)xpert " , replacement = " xintelligence expert ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence( - |-| )(g|G)athering " , replacement = " xintelligence gathering ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence( - |-| )(i|I)nformation " , replacement = " xintelligence information ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (n|N)etwork[a-z]+ | (I|i)ntelligence (n|N)etwork " , replacement = " xintelligence network ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (o|O)fficer[a-z]+ | (I|i)ntelligence (o|O)fficer " , replacement = " xintelligence officer ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (o|O)fficial[a-z]+ | (I|i)ntelligence (o|O)fficial " , replacement = " xintelligence official ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence( - |-| )(o|O)perations " , replacement = " xintelligence operations ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (r|R)eport[a-z]+ | (I|i)ntelligence (r|R)eport " , replacement = " xintelligence report ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (s|S)ervice[a-z]+ | (I|i)ntelligence (s|S)ervice " , replacement = " xintelligence service ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligence (u|U)nit[a-z]+ | (I|i)ntelligence (u|U)nit " , replacement = " xintelligence unit ")
	x <- str_replace_all(x, pattern = " (I|i)ntelligent( - |-| )(d|D)esign " , replacement = " xintelligent design ")
	x <- str_replace_all(x, pattern = " (M|m)ilitary( - |-| )(i|I)ntelligence " , replacement = " military xintelligence ")
	x <- str_replace_all(x, pattern = " (P|p)arliamentary( - |-| )(i|I)ntelligence " , replacement = " parliamentary xintelligence ")
	x <- str_replace_all(x, pattern = " (P|p)olice( - |-| )(i|I)ntelligence " , replacement = " police xintelligence ")
	x <- str_replace_all(x, pattern = " (P|p)re( - |-| )(W|w)ar( - |-| )(i|I)ntelligence " , replacement = " pre war xintelligence ")
	x <- str_replace_all(x, pattern = " (R|r)cmp (i|I)ntelligence " , replacement = " rcmp xintelligence ")
	x <- str_replace_all(x, pattern = " (S|s)ecurity( - |-| )(i|I)ntelligence " , replacement = " security xintelligence ")
	x <- str_replace_all(x, pattern = " (S|s)ource (O|o)f (i|I)ntelligence " , replacement = " source of xintelligence ")
	x <- str_replace_all(x, pattern = " (U|u)nited (S|s)tates (i|I)ntelligence " , replacement = " united states xintelligence ")
	x <- str_replace_all(x, pattern = " (I|i)solated (I|i)ncident[a-z]+ | (I|i)solated (I|i)ncident " , replacement = " xisolated incident ")
	x <- str_replace_all(x, pattern = " (K|k)iss( - |-| )(O|o)f( - |-| )(D|d)eath " , replacement = " xkiss of death ")
	x <- str_replace_all(x, pattern = " (K|k)iss[a-z]+ (G|g)oodbye | (K|k)iss (G|g)oodbye " , replacement = " xkiss goodbye ")
	x <- str_replace_all(x, pattern = " (K|k)iss[a-z]+ (T|t)hem (G|g)oodbye | (K|k)iss (T|t)hem (G|g)oodbye " , replacement = " xkiss them goodbye ")
	x <- str_replace_all(x, pattern = " (L|l)ack (O|o)f (A|a) " , replacement = " lack of a x")
	x <- str_replace_all(x, pattern = " (L|l)ack (O|o)f " , replacement = " lack of x")
	x <- str_replace_all(x, pattern = " (L|l)ack (T|t)he " , replacement = " lack the x")
	x <- str_replace_all(x, pattern = " (L|l)ack[a-z]+ (I|i)n " , replacement = " lack in x")
	x <- str_replace_all(x, pattern = " (L|l)ack[a-z]+ | (L|l)ack " , replacement = " lack x")
	x <- str_replace_all(x, pattern = " (N|n)ot (A|a)t (L|l)iberty " , replacement = " not at xliberty ")
	x <- str_replace_all(x, pattern = " (A|a)ll (Y|y)ou (L|l)ike " , replacement = " all you xlike ")
	x <- str_replace_all(x, pattern = " (A|a)s (Y|y)ou (L|l)ike " , replacement = " as you xlike ")
	x <- str_replace_all(x, pattern = " (D|d)o (Y|y)ou (L|l)ike " , replacement = " do you xlike ")
	x <- str_replace_all(x, pattern = " (G|g)od( - |-| )(L|l)ike " , replacement = " god xlike ")
	x <- str_replace_all(x, pattern = " (L|l)ike (A|a) " , replacement = " xlike a ")
	x <- str_replace_all(x, pattern = " (M|m)ore (L|l)ike " , replacement = " more xlike ")
	x <- str_replace_all(x, pattern = " (N|n)ot (Y|y)ou (L|l)ike " , replacement = " not you xlike ")
	x <- str_replace_all(x, pattern = " (S|s)omething (L|l)ike " , replacement = " something xlike ")
	x <- str_replace_all(x, pattern = " (T|t)hank (Y|y)ou (L|l)ike " , replacement = " thank you xlike ")
	x <- str_replace_all(x, pattern = " (T|t)he (L|l)ikes (O|o)f " , replacement = " the xlikes of ")
	x <- str_replace_all(x, pattern = " (T|t)reat[a-z]+ (Y|y)ou (L|l)ike | (T|t)reat (Y|y)ou (L|l)ike " , replacement = " treat you xlike ")
	x <- str_replace_all(x, pattern = " (W|w)as (L|l)ike " , replacement = " was xlike ")
	x <- str_replace_all(x, pattern = " (W|w)hether (Y|y)ou (L|l)ike " , replacement = " whether you xlike ")
	x <- str_replace_all(x, pattern = " (W|w)ould (Y|y)ou (L|l)ike " , replacement = " would you xlike ")
	x <- str_replace_all(x, pattern = " (A|a)ct[a-z]+ (L|l)ike | (A|a)ct (L|l)ike " , replacement = " act xlike ")
	x <- str_replace_all(x, pattern = " (A|a)nything (L|l)ike " , replacement = " anything xlike ")
	x <- str_replace_all(x, pattern = " (I|i)t (I|i)s (L|l)ike " , replacement = " it is xlike ")
	x <- str_replace_all(x, pattern = " (L|l)ike (I|i)t (I|i)s " , replacement = " xlike it is ")
	x <- str_replace_all(x, pattern = " (L|l)ike (I|i)t (W|w)as " , replacement = " xlike it was ")
	x <- str_replace_all(x, pattern = " (L|l)ike[a-z]+( - |-| )(I|i)t( - |-| )(O|o)r( - |-| )(N|n)ot | (L|l)ike( - |-| )(I|i)t( - |-| )(O|o)r( - |-| )(N|n)ot " , replacement = " xlike it or not ")
	x <- str_replace_all(x, pattern = " (L|l)ook[a-z]+( - |-| )(L|l)ike | (L|l)ook( - |-| )(L|l)ike " , replacement = " look xlike ")
	x <- str_replace_all(x, pattern = " (S|s)eem[a-z]+ (L|l)ike | (S|s)eem (L|l)ike " , replacement = " seem xlike ")
	x <- str_replace_all(x, pattern = " (B|b)e (L|l)ike " , replacement = " be xlike ")
	x <- str_replace_all(x, pattern = " (B|b)eing (L|l)ike " , replacement = " being xlike ")
	x <- str_replace_all(x, pattern = " (F|f)eel[a-z]+ (L|l)ike | (F|f)eel (L|l)ike " , replacement = " feel xlike ")
	x <- str_replace_all(x, pattern = " (F|f)elt (L|l)ike " , replacement = " felt xlike ")
	x <- str_replace_all(x, pattern = " 200( - |-| )(M|m)ile( - |-| )(L|l)imit[a-z]+ | 200( - |-| )(M|m)ile( - |-| )(L|l)imit " , replacement = " 200 mile xlimit ")
	x <- str_replace_all(x, pattern = " (A|a)ge( - |-| )(L|l)imit[a-z]+ | (A|a)ge( - |-| )(L|l)imit " , replacement = " age xlimit ")
	x <- str_replace_all(x, pattern = " (L|l)egal( - |-| )(L|l)imit[a-z]+ | (L|l)egal( - |-| )(L|l)imit " , replacement = " legal xlimit ")
	x <- str_replace_all(x, pattern = " (O|o)ffshore( - |-| )(L|l)imit[a-z]+ | (O|o)ffshore( - |-| )(L|l)imit " , replacement = " offshore xlimit ")
	x <- str_replace_all(x, pattern = " (S|s)peed( - |-| )(L|l)imit[a-z]+ | (S|s)peed( - |-| )(L|l)imit " , replacement = " speed xlimit ")
	x <- str_replace_all(x, pattern = " (T|t)ax( - |-| )(L|l)imit[a-z]+ | (T|t)ax( - |-| )(L|l)imit " , replacement = " tax xlimit ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (A|a) " , replacement = " lose a x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (A|a)n " , replacement = " lose an x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (I|i)ts " , replacement = " lose its x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (O|o)f (S|s)elf " , replacement = " lose of self x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (O|o)f " , replacement = " lose of x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (T|t)he " , replacement = " lose the x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (T|t)heir " , replacement = " lose their x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (Y|y)our " , replacement = " lose your x")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (W|w)eight " , replacement = " xlose weight ")
	x <- str_replace_all(x, pattern = " (N|n)ever (L|l)os[a-z]+ (H|h)ope " , replacement = " never xlose hope ")
	x <- str_replace_all(x, pattern = " (N|n)ot (L|l)os[a-z]+ (H|h)ope " , replacement = " not xlose hope ")
	x <- str_replace_all(x, pattern = " (J|j)ob( - |-| )(L|l)oss[a-z]+ | (J|j)ob( - |-| )(L|l)oss " , replacement = " job xloss ")
	x <- str_replace_all(x, pattern = " (W|w)eight( - |-| )(L|l)oss " , replacement = " weight xloss ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ ([0-9]+)( p| P)(ounds)" , replacement = " xlose \\2\\3\\4 ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+( - |-| )(L|l)ove[a-z]+ | (L|l)os[a-z]+( - |-| )(L|l)ove " , replacement = " lose xlove ")
	x <- str_replace_all(x, pattern = " (L|l)ow[a-z]+( - |-| )(P|p)oint[a-z]+ | (L|l)ow( - |-| )(P|p)oint " , replacement = " low xpoint ") 
	x <- str_replace_all(x, pattern = " (L|l)ow[a-z]+( - |-| )(R|r)egard | (L|l)ow( - |-| )(R|r)egard " , replacement = " low xregard ") 
	x <- str_replace_all(x, pattern = " (L|l)ow[a-z]+( - |-| )(E|e)xpectation[a-z]+ | (L|l)ow( - |-| )(E|e)xpectation " , replacement = " low xexpectation ")
	x <- str_replace_all(x, pattern = " (M|m)ad( - |-| )(c|C)ow " , replacement = " xmad cow ")
	x <- str_replace_all(x, pattern = " (M|m)iss[a-z]+ (A|a)n (O|o)pportunity | (M|m)iss (A|a)n (O|o)pportunity " , replacement = " xmiss an opportunity ")
	x <- str_replace_all(x, pattern = " (M|m)iss[a-z]+ (T|t)he (O|o)pportunity | (M|m)iss (T|t)he (O|o)pportunity " , replacement = " xmiss the opportunity ")
	x <- str_replace_all(x, pattern = " (M|m)itigate [a-zA-Z]+ (R|r)isk[a-z]+ | (M|m)itigate [a-zA-Z]+ (R|r)isk " , replacement = " mitigate xrisk ")
	x <- str_replace_all(x, pattern = " (M|m)itigate[a-z]+ [a-zA-Z]+ (R|r)isk[a-z]+ | (M|m)itigate[a-z]+ [a-zA-Z]+ (R|r)isk " , replacement = " mitigate xrisk ")
	x <- str_replace_all(x, pattern = " (M|m)itigate[a-z]+ (R|r)isk[a-z]+ | (M|m)itigate[a-z]+ (R|r)isk " , replacement = " mitigate xrisk ")
	x <- str_replace_all(x, pattern = " (M|m)itigate (R|r)isk[a-z]+ | (M|m)itigate (R|r)isk " , replacement = " mitigate xrisk ")
	x <- str_replace_all(x, pattern = " (M|m)ud( - |-| )(B|b)rick[a-z]+ | (M|m)ud( - |-| )(B|b)rick " , replacement = " xmud brick ")
	x <- str_replace_all(x, pattern = " (M|m)ud (W|w)all[a-z]+ | (M|m)ud (W|w)all " , replacement = " xmud wall ")
	x <- str_replace_all(x, pattern = " (M|m)ud( - |-| )(W|w)restl[a-z]+ " , replacement = " xmud wrestling ")
	x <- str_replace_all(x, pattern = " (N|n)atural( - |-| )(D|d)isaster[a-z]+ | (N|n)atural( - |-| )(D|d)isaster " , replacement = " xnatural disaster ")
	x <- str_replace_all(x, pattern = " HIV( - |-| )(N|n)egative " , replacement = " HIV xnegative ")
	x <- str_replace_all(x, pattern = " (N|n)egative( - |-| )HIV " , replacement = " xnegative HIV ")
	x <- str_replace_all(x, pattern = " (N|n)egative (T|t)est[a-z]+ | (N|n)egative (T|t)est " , replacement = " xnegative test ")
	x <- str_replace_all(x, pattern = " (T|t)est[a-z]+ (N|n)egative | (T|t)est (N|n)egative " , replacement = " test xnegative ")
	x <- str_replace_all(x, pattern = " ([0-9]+)( - |-| )(O|o)dd" , replacement = " \\1 xodd ")
	x <- str_replace_all(x, pattern = " (O|o)pen( - |-| )(M|m)arket[a-z]+ | (O|o)pen( - |-| )(M|m)arket " , replacement = " xopen market ")
	x <- str_replace_all(x, pattern = " (D|d)eclin[a-z]+ (A|a)n (O|o)pportunity " , replacement = " decline an xopportunity ")
	x <- str_replace_all(x, pattern = " (D|d)eclin[a-z]+ (T|t)he (O|o)pportunity " , replacement = " decline the xopportunity ")
	x <- str_replace_all(x, pattern = " (D|d)en[a-z]+ (A|a)n (O|o)pportunity " , replacement = " deny an xopportunity ")
	x <- str_replace_all(x, pattern = " (D|d)en[a-z]+ (T|t)he (O|o)pportunity " , replacement = " deny the xopportunity ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+ (O|o)pportunit[a-z] " , replacement = " lose xopportunity ")
	x <- str_replace_all(x, pattern = " (M|m)iss[a-z]+ (O|o)pportunit[a-z]+ | (M|m)iss opportunit[a-z]+ " , replacement = " miss xopportunity ")
	x <- str_replace_all(x, pattern = " (P|p)hoto (O|o)pportunit[a-z]+ " , replacement = " photo xopportunity ")
	x <- str_replace_all(x, pattern = " (S|s)eize[a-z]+ (T|t)he (O|o)pportunity | (S|s)eize (T|t)he (O|o)pportunity " , replacement = " seize the xopportunity ")
	x <- str_replace_all(x, pattern = " (S|s)quander[a-z]+ (A|a)n (O|o)pportunit[a-z]+ | (S|s)quander (A|a)n (O|o)pportunit[a-z]+ " , replacement = " squander an xopportunity ")
	x <- str_replace_all(x, pattern = " (W|w)indow[a-z]+( - |-| )(O|o)f( - |-| )(O|o)pportunit[a-z]+ | (W|w)indow( - |-| )(O|o)f( - |-| )(O|o)pportunit[a-z]+ " , replacement = " window of xopportunity ")
	x <- str_replace_all(x, pattern = " (I|i)n (O|o)pposition " , replacement = " in xopposition ")
	x <- str_replace_all(x, pattern = " (L|l)eader (O|o)f (T|t)he (o|O)pposition " , replacement = " leader of the xopposition ")
	x <- str_replace_all(x, pattern = " (O|o)fficial (o|O)pposition " , replacement = " official xopposition ")
	x <- str_replace_all(x, pattern = " (O|o)pposition (b|B)ench[a-z]+ | (O|o)pposition (b|B)ench " , replacement = " xopposition bench ")
	x <- str_replace_all(x, pattern = " (O|o)pposition (l|L)eader[a-z]+ | (O|o)pposition (l|L)eader " , replacement = " xopposition leader ")
	x <- str_replace_all(x, pattern = " (O|o)pposition (m|M)ember[a-z]+ | (O|o)pposition (m|M)ember " , replacement = " xopposition member ")
	x <- str_replace_all(x, pattern = " (O|o)pposition (MP|mp)[a-z]+ | (O|o)pposition (MP|mp) " , replacement = " xopposition MP ")
	x <- str_replace_all(x, pattern = " (O|o)pposition( - |-| )(p|P)art[a-z]+ " , replacement = " xopposition party ")
	x <- str_replace_all(x, pattern = " (O|o)pposition (p|P)olitician[a-z]+ | (O|o)pposition (P|p)olitician " , replacement = " xopposition politician ")
	x <- str_replace_all(x, pattern = " (T|t)he xopposition( ' |')| (T|t)he xopposition " , replacement = " the xopposition ")
	x <- str_replace_all(x, pattern = " (O|o)ver( - |-| )(P|p)rice[a-z]+ | (O|o)ver( - |-| )(P|p)rice " , replacement = " overprice ")
	x <- str_replace_all(x, pattern = " (C|c)onjugal( - |-| )(p|P)artner[a-z]+ | (C|c)onjugal( - |-| )(p|P)artner " , replacement = " conjugal xpartner ")
	x <- str_replace_all(x, pattern = " (C|c)orporate( - |-| )(p|P)artner[a-z]+ | (C|c)orporate( - |-| )(p|P)artner " , replacement = " corporate xpartner ")
	x <- str_replace_all(x, pattern = " (E|e)x( - |-| )(p|P)artner[a-z]+ | (E|e)x( - |-| )(p|P)artner " , replacement = " ex xpartner ")
	x <- str_replace_all(x, pattern = " (I|i)ndustry( - |-| )(p|P)artner[a-z]+ | (I|i)ndustry( - |-| )(p|P)artner " , replacement = " industry xpartner ")
	x <- str_replace_all(x, pattern = " (I|i)ntimate( - |-| )(p|P)artner[a-z]+ | (I|i)ntimate( - |-| )(p|P)artner " , replacement = " xintimate xpartner ")
	x <- str_replace_all(x, pattern = " (M|m)anaging( - |-| )(p|P)artner[a-z]+ | (M|m)anaging( - |-| )(p|P)artner " , replacement = " managing xpartner ")
	x <- str_replace_all(x, pattern = " (N|n)(afta|AFTA)( - |-| )(p|P)artner[a-z]+ " , replacement = " nafta xpartner ")
	x <- str_replace_all(x, pattern = " (P|p)artner[a-z]+( - |-| )(o|O)rganization[a-z]+ | (P|p)artner( - |-| )(o|O)rganization " , replacement = " xpartner organization ")
	x <- str_replace_all(x, pattern = " (S|s)ector( - |-| )(p|P)artner[a-z]+ | (S|s)ector( - |-| )(p|P)artner " , replacement = " sector xpartner ")
	x <- str_replace_all(x, pattern = " (S|s)enior( - |-| )(p|P)artner[a-z]+ | (S|s)enior( - |-| )(p|P)artner " , replacement = " senior xpartner ")
	x <- str_replace_all(x, pattern = " (S|s)ex[a-z]+( - |-| )(p|P)artner[a-z]+ | (S|s)ex( - |-| )(p|P)artner " , replacement = " sex xpartner ")
	x <- str_replace_all(x, pattern = " (S|s)hipping( - |-| )(p|P)artner[a-z]+ | (S|s)hipping( - |-| )(p|P)artner " , replacement = " shipping xpartner ")
	x <- str_replace_all(x, pattern = " (T|t)ax( - |-| )(p|P)artner[a-z]+ | (T|t)ax( - |-| )(p|P)artner " , replacement = " tax xpartner ")
	x <- str_replace_all(x, pattern = " (T|t)rading( - |-| )(p|P)artner[a-z]+ | (T|t)rading( - |-| )(p|P)artner " , replacement = " trading xpartner ")
	x <- str_replace_all(x, pattern = " (E|e)x( - |-| )(p|P)at[a-z]+ | (E|e)x( - |-| )(p|P)at " , replacement = " ex xpat ")
	x <- str_replace_all(x, pattern = " (P|p)atch[a-z]+( - |-| )(U|u)p | (P|p)atch( - |-| )(U|u)p " , replacement = " patch up ")
	x <- str_replace_all(x, pattern = " (P|p)lay[a-z]+( - |-| )(D|d)own | (P|p)lay( - |-| )(D|d)own " , replacement = " play down ")
	x <- str_replace_all(x, pattern = " (P|p)layoff( - |-| )(G|g)ame[a-z]+ | (P|p)layoff( - |-| )(G|g)ame " , replacement = " xplayoff game ")
	x <- str_replace_all(x, pattern = " (P|p)lay[a-z]+ (G|g)ame[a-z]+ | (P|p)lay (G|g)ame " , replacement = " play games ")  
	x <- str_replace_all(x, pattern = " (P|p)lay[a-z]+ (g|G)od | (P|p)lay (g|G)od " , replacement = " play god ") 
	x <- str_replace_all(x, pattern = " (P|p)lay[a-z]+ (I|i)t (C|c)ool | (P|p)lay (I|i)t (C|c)ool " , replacement = " play it cool ") 
	x <- str_replace_all(x, pattern = " (P|p)lay[a-z]+ (P|p)olitics | (P|p)lay (P|p)olitics " , replacement = " play politics ") 
	x <- str_replace_all(x, pattern = " (F|f)alse( - |-| )(p|P)ositive[a-z]+ | (F|f)alse( - |-| )(p|P)ositive " , replacement = " false xpositive ")
	x <- str_replace_all(x, pattern = " HIV( - |-| )(p|P)ositive " , replacement = " HIV xpositive ")
	x <- str_replace_all(x, pattern = " (P|p)ositive( - |-| )HIV " , replacement = " xpositive HIV ")
	x <- str_replace_all(x, pattern = " (P|p)ositive( - |-| )(I|i)dentif[a-z]+ | (P|p)ositive( - |-| )(I|i)dentif " , replacement = " positiv identif ") 
	x <- str_replace_all(x, pattern = " (P|p)ositive( - |-| )(T|t)est[a-z]+ | (P|p)ositive( - |-| )(T|t)est " , replacement = " xpositive test ")
	x <- str_replace_all(x, pattern = " (T|t)est[a-z]+( - |-| )(P|p)ositive | (T|t)est( - |-| )(P|p)ositive " , replacement = " test xpositive ")
	x <- str_replace_all(x, pattern = " (O|o)ver( - |-| )(P|p)owerful " , replacement = " overpowerful ")
	x <- str_replace_all(x, pattern = " (P|p)rison( - |-| )(g|G)uard[a-z]+ | (P|p)rison( - |-| )(g|G)uard " , replacement = " xprison guard ")
	x <- str_replace_all(x, pattern = " (P|p)rison( - |-| )(o|O)fficial[a-z]+ | (P|p)rison( - |-| )(o|O)fficial " , replacement = " xprison official ")
	x <- str_replace_all(x, pattern = " (P|p)rison( - |-| )(s|S)ystem[a-z]+ | (P|p)rison( - |-| )(s|S)ystem " , replacement = " xprison system ")
	x <- str_replace_all(x, pattern = " (P|p)roblem[a-z]+( - |-| )(S|s)olv[a-z]+ | (P|p)roblem( - |-| )(S|s)olv[a-z]+ " , replacement = " problem solve ") 
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+( - |-| )(P|p)roductivity " , replacement = " lose xproductivity ")
	x <- str_replace_all(x, pattern = " (I|i)n( - |-| )(P|p)rogress " , replacement = " in xprogress ")
	x <- str_replace_all(x, pattern = " (P|p)rogressive( - |-| )(D|d)isorder " , replacement = " xprogressive disorder ")
	x <- str_replace_all(x, pattern = " (P|p)rotestant[a-z]+ | (P|p)rotestant " , replacement = " xprotestant ")
	x <- str_replace_all(x, pattern = " (A|a)ir( - |-| )(Q|q)uality " , replacement = " air xquality ")
	x <- str_replace_all(x, pattern = " (F|f)uel( - |-| )(Q|q)uality " , replacement = " fuel xquality ")
	x <- str_replace_all(x, pattern = " (P|p)oor( - |-| )(Q|q)uality " , replacement = " poor xquality ")
	x <- str_replace_all(x, pattern = " (Q|q)uality( - |-| )(O|o)f( - |-| )(L|l)ife " , replacement = " xquality of life ")
	x <- str_replace_all(x, pattern = " (W|w)ater( - |-| )(Q|q)uality " , replacement = " water xquality ")
	x <- str_replace_all(x, pattern = " (R|r)easonable( - |-| )(A|a)ccommodation " , replacement = " xreasonable xaccommodation ")
	x <- str_replace_all(x, pattern = " (R|r)easonable( - |-| )(D|d)oubt " , replacement = " xreasonable xdoubt ")
	x <- str_replace_all(x, pattern = " (R|r)efus[a-z]+ (T|t)o " , replacement = " refuse to x")
	x <- str_replace_all(x, pattern = " (T|t)ax( - |-| )(R|r)elief " , replacement = " tax xrelief ")
	x <- str_replace_all(x, pattern = " (H|h)uman( - |-| )(R|r)esourc[a-z]+ " , replacement = " human xresource ")
	x <- str_replace_all(x, pattern = " (R|r)esource[a-z]+ (m|M)inister | (R|r)esource (m|M)inister " , replacement = " xresource minister ")
	x <- str_replace_all(x, pattern = " (I|i)n (M|m)any (R|r)espects " , replacement = " in many xrespects ")
	x <- str_replace_all(x, pattern = " (I|i)n (R|r)espect (O|o)f " , replacement = " in xrespect of ")
	x <- str_replace_all(x, pattern = " (I|i)n (S|s)ome (R|r)espects " , replacement = " in some xrespects ")
	x <- str_replace_all(x, pattern = " (I|i)n (T|t)hat (R|r)espect " , replacement = " in that xrespect ")
	x <- str_replace_all(x, pattern = " (I|i)n (T|t)his (R|r)espect " , replacement = " in this xrespect ")
	x <- str_replace_all(x, pattern = " (W|w)ith (R|r)espect (T|t)o " , replacement = " with xrespect to ")
	x <- str_replace_all(x, pattern = " (C|c)laim[a-z]+ (O|o)f (R|r)esponsib[a-z]+ | (C|c)laim (O|o)f (R|r)esponsib[a-z]+ " , replacement = " claim of xresponsibility ")
	x <- str_replace_all(x, pattern = " (C|c)laim[a-z]+ (R|r)esponsib[a-z]+ | (C|c)laim (R|r)esponsib[a-z]+ " , replacement = " claim xresponsibility ")
	x <- str_replace_all(x, pattern = " (C|c)onflicting (R|r)esponsib[a-z]+ " , replacement = " conflicting xresponsibility ")
	x <- str_replace_all(x, pattern = " (C|c)riminal[a-z]+( - |-| )(R|r)esponsib[a-z]+ | (C|c)riminal( - |-| )(R|r)esponsib[a-z]+ " , replacement = " xcriminal xresponsibility ")
	x <- str_replace_all(x, pattern = " (D|d)en[a-z]+ (R|r)esponsib[a-z]+ " , replacement = " deny xresponsibility ")
	x <- str_replace_all(x, pattern = " (F|f)ederal[a-z]+( - |-| )(R|r)esponsib[a-z]+ | (F|f)ederal( - |-| )(R|r)esponsib[a-z]+ " , replacement = " federal xresponsibility ")
	x <- str_replace_all(x, pattern = " (M|m)inisterial( - |-| )(R|r)esponsib[a-z]+ " , replacement = " ministerial xresponsibility ")
	x <- str_replace_all(x, pattern = " (P|p)rovincial( - |-| )(R|r)esponsib[a-z]+ " , replacement = " provincial xresponsibility ")
	x <- str_replace_all(x, pattern = " (R|r)esponsib[a-z]+ (F|f)or " , replacement = " xresponsible for ")
	x <- str_replace_all(x, pattern = " (S|s)hift[a-z]+ (R|r)esponsib[a-z]+ | (S|s)hift (R|r)esponsib[a-z]+ " , replacement = " shift xresponsibility ")
	x <- str_replace_all(x, pattern = " (T|t)ake (O|o)ver (R|r)esponsib[a-z]+ " , replacement = " take over xresponsibility ")
	x <- str_replace_all(x, pattern = " (O|o)ut( - |-| )(R|r)ight " , replacement = " outright ")
	x <- str_replace_all(x, pattern = " (R|r)ight( - |-| )(H|h)and[a-z]+ | (R|r)ight( - |-| )hand " , replacement = " xright hand ")
	x <- str_replace_all(x, pattern = " (R|r)ights( - |-| )(A|a)bus[a-z]+ " , replacement = " xrights abuse ")
	x <- str_replace_all(x, pattern = " (R|r)ights( - |-| )(C|c)omplaint[a-z]+ | (R|r)ights( - |-| )(C|c)omplaint " , replacement = " xrights complaint ")
	x <- str_replace_all(x, pattern = " (R|r)ights( - |-| )(R|r)ecord[a-z]+ | (R|r)ights( - |-| )(R|r)ecord " , replacement = " xrights record ")
	x <- str_replace_all(x, pattern = " (R|r)ights( - |-| )(V|v)iolat[a-z]+ " , replacement = " xrights violation ")
	x <- str_replace_all(x, pattern = " (S|s)afety( - |-| )(b|B)oard[a-z]+ | (S|s)afety( - |-| )(b|B)oard " , replacement = " xsafety board ")
	x <- str_replace_all(x, pattern = " (S|s)afety( - |-| )(I|i)nspection[a-z]+ | (S|s)afety( - |-| )(I|i)nspection " , replacement = " xsafety inspection ")
	x <- str_replace_all(x, pattern = " (S|s)afety( - |-| )(m|M)inister[a-z]+ | (S|s)afety( - |-| )(m|M)inister " , replacement = " xsafety minister ")
	x <- str_replace_all(x, pattern = " (F|f)or (S|s)crap " , replacement = " for xscrap ")
	x <- str_replace_all(x, pattern = " (O|o)f (S|s)crap " , replacement = " of xscrap ")
	x <- str_replace_all(x, pattern = " (S|s)crap( - |-| )(M|m)etal " , replacement = " xscrap metal ")
	x <- str_replace_all(x, pattern = " (S|s)crap (O|o)f " , replacement = " xscrap of ")
	x <- str_replace_all(x, pattern = " (S|s)crap (T|t)ire[a-z]+ | (S|s)crap (T|t)ire " , replacement = " xscrap tire ")
	x <- str_replace_all(x, pattern = " (S|s)crap( - |-| )yard[a-z]+ | (S|s)crap( - |-| )(Y|y)ard " , replacement = " xscrap yard ")
	x <- str_replace_all(x, pattern = " (F|f)ood (S|s)craps " , replacement = " food xscraps ")
	x <- str_replace_all(x, pattern = " (T|t)able (S|s)craps " , replacement = " table xscraps ")
	x <- str_replace_all(x, pattern = " (V|v)egetable (S|s)craps " , replacement = " vegetable xscraps ")
	x <- str_replace_all(x, pattern = " (U|u)nlikely (T|t)o (S|s)ecure " , replacement = " unlikely to xsecure ")
	x <- str_replace_all(x, pattern = " (S|s)eiz[a-z]+ (T|t)he (D|d)ay " , replacement = " seize the day ")
	x <- str_replace_all(x, pattern = " (A|a) (S|s)ense " , replacement = " a xsense ") ## Error in spacing fixed
	x <- str_replace_all(x, pattern = " (C|c)ould (S|s)ense " , replacement = " could xsense ")
	x <- str_replace_all(x, pattern = " (E|e)very (S|s)ense " , replacement = " every xsense ")
	x <- str_replace_all(x, pattern = " (M|m)y (S|s)ense " , replacement = " my xsense ")
	x <- str_replace_all(x, pattern = " (N|n)ot (S|s)ense " , replacement = " not xsense ")
	x <- str_replace_all(x, pattern = " (O|o)ne (S|s)ense " , replacement = " one xsense ")
	x <- str_replace_all(x, pattern = " (S|s)ense (O|o)f " , replacement = " xsense of ")
	x <- str_replace_all(x, pattern = " (S|s)ense (T|t)hat " , replacement = " xsense that ")
	x <- str_replace_all(x, pattern = " (T|t)hat (S|s)ense " , replacement = " that xsense ")
	x <- str_replace_all(x, pattern = " (T|t)his (S|s)ense " , replacement = " this xsense ")
	x <- str_replace_all(x, pattern = " (H|h)yper( - |-| )(S|s)ensitiv[a-z]+ " , replacement = " hypersensitive ")
	x <- str_replace_all(x, pattern = " (T|t)ime( - |-| )(S|s)ensitiv[a-z]+ " , replacement = " time xsensitive ")
	x <- str_replace_all(x, pattern = " (S|s)hak[a-z]+ (H|h)and[a-z]+ | (S|s)hak[a-z]+ (H|h)and " , replacement = " xshake hand ")
	x <- str_replace_all(x, pattern = " (S|s)hak[a-z]+ (O|o)f (H|h)ands " , replacement = " xshake of hands ")
	x <- str_replace_all(x, pattern = " (S|s)heltered( - |-| )(L|l)ife " , replacement = " xsheltered life ")
	x <- str_replace_all(x, pattern = " (A|a) (S|s)hield[a-z]+ | (A|a) (S|s)hield " , replacement = " a xshield ")
	x <- str_replace_all(x, pattern = " (D|d)efence( - |-| )(s|S)hield[a-z]+ | (D|d)efence( - |-| )(s|S)hield " , replacement = " defence xshield ")
	x <- str_replace_all(x, pattern = " (D|d)efense( - |-| )(s|S)hield[a-z]+ | (D|d)efense( - |-| )(s|S)hield " , replacement = " defense xshield ")
	x <- str_replace_all(x, pattern = " (E|e)uropean( - |-| )(s|S)hield[a-z]+ | (E|e)uropean( - |-| )(s|S)hield " , replacement = " european xshield ")
	x <- str_replace_all(x, pattern = " (M|m)issile( - |-| )(s|S)hield[a-z]+ | (M|m)issile( - |-| )(s|S)hield " , replacement = " missile xshield ")
	x <- str_replace_all(x, pattern = " (S|s)ecurity( - |-| )(s|S)hield[a-z]+ | (S|s)ecurity( - |-| )(s|S)hield " , replacement = " security xshield ")
	x <- str_replace_all(x, pattern = " (S|s)hield( - |-| )(i|I)nterceptor[a-z]+ | (S|s)hield( - |-| )(i|I)nterceptor " , replacement = " xshield interceptor ")
	x <- str_replace_all(x, pattern = " (S|s)hield( ' |')s " , replacement = " xshield\\2s ")
	x <- str_replace_all(x, pattern = " (S|s)igh (O|o)f (R|r)elief " , replacement = " xsigh of relief ")
	x <- str_replace_all(x, pattern = " (A|a) (S|s)ignificant[a-z]+ | (A|a) (S|s)ignificant " , replacement = " a xsignificant ")
	x <- str_replace_all(x, pattern = " (S|s)ignificant (R|r)isk " , replacement = " xsignificant risk ")
	x <- str_replace_all(x, pattern = " (A|a) (S|s)ink " , replacement = " a xsink ")
	x <- str_replace_all(x, pattern = " (B|b)athroom (S|s)ink " , replacement = " bathroom xsink ")
	x <- str_replace_all(x, pattern = " (F|f)loor (A|a)nd (S|s)ink " , replacement = " floor and xsink ")
	x <- str_replace_all(x, pattern = " (K|k)itchen( - |-| )(S|s)ink " , replacement = " kitchen xsink ")
	x <- str_replace_all(x, pattern = " (T|t)he (S|s)ink " , replacement = " the xsink ")
	x <- str_replace_all(x, pattern = " (O|o)f (S|s)inks " , replacement = " of xsinks ")
	x <- str_replace_all(x, pattern = " (S|s)ky( ' |')s( - |-| )(T|t)he( - |-| )(L|l)imit " , replacement = " sky is the limit ")
	x <- str_replace_all(x, pattern = " (G|g)rand( - |-| )(s|S)lam[a-z]+ | (G|g)rand( - |-| )(s|S)lam " , replacement = " grand xslam ")
	x <- str_replace_all(x, pattern = " (S|s)lam( - |-| )(D|d)unk " , replacement = " xslam dunk ")
	x <- str_replace_all(x, pattern = " (S|s)lamdance[a-z]+ | (S|s)lamdance " , replacement = " xslamdance ")
	x <- str_replace_all(x, pattern = " (S|s)lammer[a-z]+ | (S|s)lammer " , replacement = " xslammer ")
	x <- str_replace_all(x, pattern = " (S|s)lip[a-z]+( - |-| )(U|u)p | (S|s)lip( - |-| )(U|u)p " , replacement = " slip up ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(e|E)ducation[a-z]+ | (S|s)pecial( - |-| )(e|E)ducation " , replacement = " xspecial education ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(i|I)nterest[a-z]+ | (S|s)pecial( - |-| )(i|I)nterest " , replacement = " xspecial interest ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(i|I)nvestigat[a-z]+ " , replacement = " xspecial investigation ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(N|n)eeds " , replacement = " xspecial needs ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(o|O)perations " , replacement = " xspecial operations ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(p|P)olice " , replacement = " xspecial police ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(p|P)rosecutor[a-z]+ | (S|s)pecial( - |-| )(p|P)rosecutor " , replacement = " xspecial prosecutor ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(u|U)nit[a-z]+ | (S|s)pecial( - |-| )(u|U)nit " , replacement = " xspecial unit ")
	x <- str_replace_all(x, pattern = " (S|s)pecial( - |-| )(v|V)ictim[a-z]+( - |-| )(u|U)nit | (S|s)pecial( - |-| )(v|V)ictim( - |-| )(u|U)nit " , replacement = " xspecial xvictims unit ")
	x <- str_replace_all(x, pattern = " (S|s)pecial[a-z]+( - |-| )(f|F)orce[a-z]+ | (S|s)pecial( - |-| )(f|F)orce " , replacement = " xspecial force ")
	x <- str_replace_all(x, pattern = " (C|c)hristian( - |-| )(s|S)pirit[a-z]+ | (C|c)hristian( - |-| )(s|S)pirit " , replacement = " christian xspirit ")
	x <- str_replace_all(x, pattern = " (D|d)ivine( - |-| )(s|S)pirit[a-z]+ | (D|d)ivine( - |-| )(s|S)pirit " , replacement = " divine xspirit ")
	x <- str_replace_all(x, pattern = " (B|b)eer (O|o)r (S|s)pirit[a-z]+ | (B|b)eer (O|o)r (S|s)pirit " , replacement = " beer or xspirits ")
	x <- str_replace_all(x, pattern = " (F|f)rom (S|s)pirits " , replacement = " from xspirits ")
	x <- str_replace_all(x, pattern = " (O|o)unc[a-z]+ (O|o)f (S|s)pirits " , replacement = " ounce of xspirits ")
	x <- str_replace_all(x, pattern = " (W|w)ine (A|a)nd (S|s)pirits " , replacement = " wine and xspirits ")
	x <- str_replace_all(x, pattern = " (S|s)tick[a-z]+ (B|b)y | (S|s)tick (B|b)y " , replacement = " stick by ")
	x <- str_replace_all(x, pattern = " (S|s)tick[a-z]+ (I|i)t (O|o)ut | (S|s)tick (I|i)t (O|o)ut " , replacement = " stick it out ")
	x <- str_replace_all(x, pattern = " (S|s)tick[a-z]+ (T|t)o (I|i)t | (S|s)tick (T|t)o (I|i)t " , replacement = " stick to it ")
	x <- str_replace_all(x, pattern = " (S|s)tick[a-z]+ (U|u)p (F|f)or | (S|s)tick (U|u)p (F|f)or " , replacement = " stick up for ")
	x <- str_replace_all(x, pattern = " (S|s)tick[a-z]+ (W|w)ith | (S|s)tick (W|w)ith " , replacement = " stick with ")
	x <- str_replace_all(x, pattern = " (S|s)tiff( - |-| )(U|u)pper " , replacement = " xstiff upper ")
	x <- str_replace_all(x, pattern = " ([0-9]+)( - |-| )strains" , replacement = " \\1 xstrains ")
	x <- str_replace_all(x, pattern = " (F|f)lu( - |-| )(S|s)train[a-z]+ | (F|f)lu( - |-| )(S|s)train " , replacement = " flu xstrain ")
	x <- str_replace_all(x, pattern = " (H|h)uman( - |-| )(S|s)train[a-z]+ | (H|h)uman( - |-| )(S|s)train " , replacement = " human xstrain ")
	x <- str_replace_all(x, pattern = " (L|l)ethal( - |-| )(S|s)train " , replacement = " lethal xstrain ")
	x <- str_replace_all(x, pattern = " (S|s)train[a-z]+ (O|o)f | (S|s)train (O|o)f " , replacement = " xstrain of ")
	x <- str_replace_all(x, pattern = " (S|s)uperbug( - |-| )(S|s)train[a-z]+ | (S|s)uperbug( - |-| )(S|s)train " , replacement = " superbug xstrain ")
	x <- str_replace_all(x, pattern = " (V|v)iral( - |-| )(S|s)train[a-z]+ | (V|v)iral( - |-| )(S|s)train " , replacement = " viral xstrain ")
	x <- str_replace_all(x, pattern = " (S|s)tress[a-z]+ (T|t)hat | (S|s)tress (T|t)hat " , replacement = " xstress that ")
	x <- str_replace_all(x, pattern = " (S|s)tress[a-z]+ (T|t)he | (S|s)tress (T|t)he " , replacement = " xstress the ")
	x <- str_replace_all(x, pattern = " (S|s)tress[a-z]+ (T|t)here | (S|s)tress (T|t)here " , replacement = " xstress there ")
	x <- str_replace_all(x, pattern = " (S|s)tress[a-z]+ (T|t)hey | (S|s)tress (T|t)hey " , replacement = " xstress they ")
	x <- str_replace_all(x, pattern = " (T|t)o (S|s)tress " , replacement = " to xstress ")
	x <- str_replace_all(x, pattern = " (S|s)tumb[a-z]+( - |-| )(U|u)pon " , replacement = " xstumble upon ")
	x <- str_replace_all(x, pattern = " (A|a) (S|s)uperior " , replacement = " a xsuperior ")
	x <- str_replace_all(x, pattern = " (S|s)uperior( - |-| )(a|A)uthorit[a-z]+ | (S|s)uperior( - |-| )(a|A)uthorit " , replacement = " xsuperior authority ")
	x <- str_replace_all(x, pattern = " (S|s)uperior( - |-| )(c|C)ourt[a-z]+ | (S|s)uperior( - |-| )(c|C)ourt " , replacement = " xsuperior court ")
	x <- str_replace_all(x, pattern = " (S|s)uperior (D|d)esign " , replacement = " xsuperior design ")
	x <- str_replace_all(x, pattern = "%( - |-| )(S|s)upport[a-z]+ |%( - |-| )(S|s)upport " , replacement = "% xsupport ")
	x <- str_replace_all(x, pattern = " ([0-9]+) (in support)" , replacement = " \\1 in xsupport ")
	x <- str_replace_all(x, pattern = " ([0-9]+)( - |-| )(support)" , replacement = " \\1 xsupport ")
	x <- str_replace_all(x, pattern = " (A|a)ir( - |-| )(S|s)upport " , replacement = " air xsupport ")
	x <- str_replace_all(x, pattern = " (C|c)hild( - |-| )(S|s)upport " , replacement = " child xsupport ")
	x <- str_replace_all(x, pattern = " (D|d)iminish[a-z]+( - |-| )(S|s)upport | (D|d)iminish( - |-| )(S|s)upport " , replacement = " diminish xsupport ")
	x <- str_replace_all(x, pattern = " (D|d)o (Y|y)ou (S|s)upport " , replacement = " do you xsupport ")
	x <- str_replace_all(x, pattern = " (I|i)ncome( - |-| )(S|s)upport " , replacement = " income xsupport ")
	x <- str_replace_all(x, pattern = " (L|l)ife( - |-| )(S|s)upport " , replacement = " life xsupport ")
	x <- str_replace_all(x, pattern = " (L|l)os[a-z]+( - |-| )(S|s)upport " , replacement = " lose xsupport ")
	x <- str_replace_all(x, pattern = " (M|m)aterial( - |-| )(S|s)upport " , replacement = " material xsupport ")
	x <- str_replace_all(x, pattern = " (P|p)arty( ' |')s( - |-| )(S|s)upport | (P|p)arty( - |-| )(S|s)upport " , replacement = " party xsupport ")
	x <- str_replace_all(x, pattern = " (P|p)ercent( - |-| )(S|s)upport[a-z]+ | (P|p)ercent( - |-| )(S|s)upport " , replacement = " percent xsupport ")
	x <- str_replace_all(x, pattern = " (P|p)ublic( - |-| )(S|s)upport " , replacement = " public xsupport ")
	x <- str_replace_all(x, pattern = " (S|s)pousal( - |-| )(S|s)upport " , replacement = " spousal xsupport ")
	x <- str_replace_all(x, pattern = " (S|s)upport( - |-| )(A|a)gency[a-z]+ | (S|s)upport( - |-| )(A|a)gency " , replacement = " xsupport agency ")
	x <- str_replace_all(x, pattern = " (S|s)upport( - |-| )(E|e)rod[a-z]+ " , replacement = " xsupport eroding ")
	x <- str_replace_all(x, pattern = " (S|s)upport (H|h)as " , replacement = " xsupport has ")
	x <- str_replace_all(x, pattern = " (S|s)upport (I|i)n (T|t)he (P|p)olls " , replacement = " xsupport in the polls ")
	x <- str_replace_all(x, pattern = " (S|s)upport (I|i)s " , replacement = " xsupport is ")
	x <- str_replace_all(x, pattern = " (S|s)upport (M|m)ay (B|b)e " , replacement = " xsupport may be ")
	x <- str_replace_all(x, pattern = " (S|s)upport (O|o)f ([0-9]+)" , replacement = " xsupport of \\2 ")
	x <- str_replace_all(x, pattern = " (S|s)upport (O|o)f (A|a)t (L|l)east " , replacement = " xsupport of at least ")
	x <- str_replace_all(x, pattern = " (S|s)upport (O|o)f (O|o)nly " , replacement = " xsupport of only ")
	x <- str_replace_all(x, pattern = " (S|s)upport (O|o)f (T|t)error[a-z]+ | (S|s)upport of terror " , replacement = " xsupport of terror ")
	x <- str_replace_all(x, pattern = " (S|s)upport( - |-| )(P|p)ayment[a-z]+ | (S|s)upport( - |-| )(P|p)ayment " , replacement = " xsupport payment ")
	x <- str_replace_all(x, pattern = " (S|s)upport( - |-| )(P|p)rogram " , replacement = " xsupport program ")
	x <- str_replace_all(x, pattern = " (S|s)upport( - |-| )(S|s)taff " , replacement = " xsupport staff ")
	x <- str_replace_all(x, pattern = " (S|s)upport( - |-| )(T|t)roop[a-z]+ | (S|s)upport( - |-| )(T|t)roop " , replacement = " xsupport troops ")
	x <- str_replace_all(x, pattern = " (S|s)upport[a-z]+ (A|a)ppear[a-z]+ | (S|s)upport (A|a)ppear[a-z]+ " , replacement = " xsupport appears ")
	x <- str_replace_all(x, pattern = " (S|s)upport[a-z]+ (A|a)t ([0-9]+)| (S|s)upport (A|a)t ([0-9]+)" , replacement = " xsupport at \\2 ")
	x <- str_replace_all(x, pattern = " (S|s)upport[a-z]+ (E|e)ither | (S|s)upport (E|e)ither " , replacement = " xsupport either ")
	x <- str_replace_all(x, pattern = " (S|s)upport[a-z]+ (T|t)error[a-z]+ | (S|s)upport (T|t)error " , replacement = " xsupport terror ")
	x <- str_replace_all(x, pattern = " (T|t)error[a-z]+( - |-| )(S|s)upport | (T|t)error( - |-| )(S|s)upport " , replacement = " terror xsupport ")
	x <- str_replace_all(x, pattern = " (U|u)ndermine (S|s)upport " , replacement = " undermine xsupport ")
	x <- str_replace_all(x, pattern = " (W|w)ho(|m) (T|t)o (S|s)upport " , replacement = " who to xsupport ")
	x <- str_replace_all(x, pattern = " (S|s)upporting( - |-| )(A|a)ctor " , replacement = " xsupporting actor ")
	x <- str_replace_all(x, pattern = " (S|s)upporting( - |-| )(A|a)ctress " , replacement = " xsupporting actress ")
	x <- str_replace_all(x, pattern = " (S|s)upporting( - |-| )(D|d)ocument[a-z]+ | (S|s)upporting (D|d)ocument " , replacement = " xsupporting document ")
	x <- str_replace_all(x, pattern = " (S|s)urvival( - |-| )(O|o)f( - |-| )(T|t)he( - |-| )(F|f)ittest " , replacement = " xsurvival of the fittest ")
	x <- str_replace_all(x, pattern = " (S|s)urvival( - |-| )(R|r)ate[a-z]+ | (S|s)urvival( - |-| )(R|r)ate " , replacement = " xsurvival rate ")
	x <- str_replace_all(x, pattern = " (S|s)urvived (B|b)y " , replacement = " xsurvived by ")
	x <- str_replace_all(x, pattern = " (S|s)wear[a-z]+ (A|a)n | (S|s)wear (A|a)n " , replacement = " xswear an ")
	x <- str_replace_all(x, pattern = " (S|s)wear[a-z]+ (I|i)n | (S|s)wear (I|i)n " , replacement = " xswear in ")
	x <- str_replace_all(x, pattern = " (S|s)wear[a-z]+ (T|t)hat | (S|s)wear (T|t)hat " , replacement = " xswear that ")
	x <- str_replace_all(x, pattern = " (S|s)wear[a-z]+ (T|t)hey | (S|s)wear (T|t)hey " , replacement = " xswear they ")
	x <- str_replace_all(x, pattern = " (T|t)amper( - |-| )(P|p)roof " , replacement = " xtamper proof ")
	x <- str_replace_all(x, pattern = " (T|t)ears (O|o)f (H|h)appiness " , replacement = " xtears of happiness ")
	x <- str_replace_all(x, pattern = " (T|t)ears (O|o)f (J|j)oy " , replacement = " xtears of joy ")
	x <- str_replace_all(x, pattern = " (T|t)ears (O|o)f (R|r)elief " , replacement = " xtears of relief ")
	x <- str_replace_all(x, pattern = " (T|t)ears (O|o)f (T|t)hanks " , replacement = " xtears of thanks ")
	x <- str_replace_all(x, pattern = " (F|f)or (T|t)ender " , replacement = " for xtender ")
	x <- str_replace_all(x, pattern = " (O|o)riginal (T|t)ender " , replacement = " original xtender ")
	x <- str_replace_all(x, pattern = " (P|p)re( - |-| )(T|t)ender " , replacement = " pre xtender ")
	x <- str_replace_all(x, pattern = " (P|p)ublic( - |-| )(T|t)ender " , replacement = " public xtender ")
	x <- str_replace_all(x, pattern = " (T|t)ender( - |-| )(E|e)stimat[a-z]+ | (T|t)ender( - |-| )(E|e)stimat " , replacement = " xtender estimate ")
	x <- str_replace_all(x, pattern = " (T|t)ender[a-z]+ (B|b)y | (T|t)ender (B|b)y " , replacement = " xtender by ")
	x <- str_replace_all(x, pattern = " (T|t)ender[a-z]+ (F|f)or | (T|t)ender (F|f)or " , replacement = " xtender for ")
	x <- str_replace_all(x, pattern = " (T|t)ender[a-z]+ (I|i)t | (T|t)ender (I|i)t " , replacement = " xtender it ")
	x <- str_replace_all(x, pattern = " (T|t)ender[a-z]+( - |-| )(P|p)rocess | (T|t)ender( - |-| )(P|p)rocess " , replacement = " xtender process ")
	x <- str_replace_all(x, pattern = " (T|t)ender[a-z]+( - |-| )(P|p)rojection[a-z]+ | (T|t)ender( - |-| )(P|p)rojection " , replacement = " xtender projection ")
	x <- str_replace_all(x, pattern = " (T|t)ender[a-z]+( - |-| )(T|t)o | (T|t)ender( - |-| )(T|t)o " , replacement = " xtender to ")
	x <- str_replace_all(x, pattern = " (T|t)he (T|t)ender[a-z]+ | (T|t)he (T|t)ender " , replacement = " the xtender ")
	x <- str_replace_all(x, pattern = " (T|t)o (T|t)ender " , replacement = " to xtender ")
	x <- str_replace_all(x, pattern = " (W|w)as (T|t)ender[a-z]+ | (W|w)as (T|t)ender " , replacement = " was xtender ") 
	x <- str_replace_all(x, pattern = " (W|w)ill (T|t)ender " , replacement = " will xtender ")
	x <- str_replace_all(x, pattern = " (T|t)oilet[a-z]+ | (T|t)oilet " , replacement = " xtoilet ")
	x <- str_replace_all(x, pattern = " (H|h)e (T|t)oo " , replacement = " he xtoo ")
	x <- str_replace_all(x, pattern = " (S|s)he (T|t)oo " , replacement = " she xtoo ")
	x <- str_replace_all(x, pattern = " (S|s)o (T|t)oo " , replacement = " so xtoo ")
	x <- str_replace_all(x, pattern = " (T|t)hem (T|t)oo " , replacement = " them xtoo ")
	x <- str_replace_all(x, pattern = " (T|t)his (T|t)oo " , replacement = " this xtoo ")
	x <- str_replace_all(x, pattern = " (T|t)oo (A|a)re " , replacement = " xtoo are ")
	x <- str_replace_all(x, pattern = " (T|t)oo (A|a)s " , replacement = " xtoo as ")
	x <- str_replace_all(x, pattern = " (T|t)oo (B|b)ecause " , replacement = " xtoo because ")
	x <- str_replace_all(x, pattern = " (T|t)oo (C|c)an " , replacement = " xtoo can ")
	x <- str_replace_all(x, pattern = " (T|t)oo (H|h)ave " , replacement = " xtoo have ")
	x <- str_replace_all(x, pattern = " (T|t)oo (I|i)f " , replacement = " xtoo if ")
	x <- str_replace_all(x, pattern = " (T|t)oo (I|i)s " , replacement = " xtoo is ")
	x <- str_replace_all(x, pattern = " (T|t)oo (T|t)hat " , replacement = " xtoo that ")
	x <- str_replace_all(x, pattern = " (T|t)oo (T|t)he " , replacement = " xtoo the ")
	x <- str_replace_all(x, pattern = " (T|t)oo (T|t)here " , replacement = " xtoo there ")
	x <- str_replace_all(x, pattern = " (T|t)oo (T|t)hey " , replacement = " xtoo they ")
	x <- str_replace_all(x, pattern = " (T|t)oo (T|w)as " , replacement = " xtoo was ")
	x <- str_replace_all(x, pattern = " (T|t)oo (W|w)hen " , replacement = " xtoo when ")
	x <- str_replace_all(x, pattern = " (T|t)oo (W|w)ill " , replacement = " xtoo will ")
	x <- str_replace_all(x, pattern = " (T|t)oo (W|w)ith " , replacement = " xtoo with ")
	x <- str_replace_all(x, pattern = " (T|t)oo (W|w)ould " , replacement = " xtoo would ")
	x <- str_replace_all(x, pattern = " (T|t)oo " , replacement = " too x")
	x <- str_replace_all(x, pattern = " (T|t)oo x(C|c)lose (T|t)o (C|c)all " , replacement = " xtoo close to call ")
	x <- str_replace_all(x, pattern = " (T|t)oo x(G|g)ood " , replacement = " xtoo good ")
	x <- str_replace_all(x, pattern = " (T|t)oo x(H|h)appy " , replacement = " xtoo happy ")
	x <- str_replace_all(x, pattern = " (T|t)oo x(H|h)elpful " , replacement = " xtoo helpful ")
	x <- str_replace_all(x, pattern = " (T|t)oo x(I|i)mportant " , replacement = " xtoo important ")
	x <- str_replace_all(x, pattern = " (T|t)oo x(N|n)ice " , replacement = " xtoo nice ")
	x <- str_replace_all(x, pattern = " (T|t)oo x(P|p)ositive " , replacement = " xtoo positive ")
	x <- str_replace_all(x, pattern = " (T|t)oxico[a-z]+ " , replacement = " xtoxicology ")
	x <- str_replace_all(x, pattern = " (A|a)bus[a-z]+ (O|o)f (T|t)rust " , replacement = " abuse of xtrust ")
	x <- str_replace_all(x, pattern = " (B|b)etrayal (O|o)f (T|t)rust " , replacement = " betrayal of xtrust ")
	x <- str_replace_all(x, pattern = " (B|b)reach (O|o)f (T|t)rust " , replacement = " breach of xtrust ")
	x <- str_replace_all(x, pattern = " (I|i)ncome( - |-| )(T|t)rust[a-z]+ | (I|i)ncome( - |-| )(T|t)rust " , replacement = " income xtrust ")
	x <- str_replace_all(x, pattern = " (T|t)rust( - |-| )(F|f)und[a-z]+ | (T|t)rust( - |-| )(F|f)und " , replacement = " xtrust fund ")
	x <- str_replace_all(x, pattern = " (U|u)nable (T|t)o " , replacement = " unable to x")
	x <- str_replace_all(x, pattern = " (A|a)merican[a-z]+( - |-| )(U|u)nity " , replacement = " american xunity ")
	x <- str_replace_all(x, pattern = " (C|c)anad[a-z]+( - |-| )(U|u)nity " , replacement = " canadian xunity ")
	x <- str_replace_all(x, pattern = " (N|n)ational( - |-| )(U|u)nity " , replacement = " national xunity ")
	x <- str_replace_all(x, pattern = " (U|u)pside( - |-| )(D|d)own " , replacement = " xupside down ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(c|C)hair[a-z]+ | (V|v)ice( - |-| )(c|C)hair " , replacement = " xvice chair ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(c|C)hancellor[a-z]+ | (V|v)ice( - |-| )(c|C)hancellor " , replacement = " xvice chancellor ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(c|C)hief[a-z]+ | (V|v)ice( - |-| )(c|C)hief " , replacement = " xvice chief ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(c|C)onsul[a-z]+ " , replacement = " xvice consul ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(p|P)remier[a-z]+ | (V|v)ice( - |-| )(p|P)remier " , replacement = " xvice premier ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(p|P)resident[a-z]+ | (V|v)ice( - |-| )(p|P)resident " , replacement = " xvice president ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(p|P)rincipal[a-z]+ | (V|v)ice( - |-| )(p|P)rincipal " , replacement = " xvice principal ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(r|R)egal[a-z]+ | (V|v)ice( - |-| )(r|R)egal " , replacement = " xvice regal ")
	x <- str_replace_all(x, pattern = " (V|v)ice( - |-| )(V|v)ersa " , replacement = " xvice versa ")
	x <- str_replace_all(x, pattern = " (N|n)ight( - |-| )(V|v)ision " , replacement = " night xvision ")
	x <- str_replace_all(x, pattern = " (P|p)eripheral( - |-| )(V|v)ision " , replacement = " peripheral xvision ")
	x <- str_replace_all(x, pattern = " (V|v)ital( - |-| )(S|s)ign[a-z]+ | (V|v)ital( - |-| )(S|s)ign " , replacement = " xvital sign ")
	x <- str_replace_all(x, pattern = " (W|w)alk[a-z]+( - |-| )(O|o)n( - |-| )(A|a)ir | (W|w)alk( - |-| )(O|o)n( - |-| )(A|a)ir " , replacement = " walk on air ")
	x <- str_replace_all(x, pattern = " (C|c)limate( - |-| )(W|w)arm[a-z]+ | (C|c)limate( - |-| )(W|w)arm " , replacement = " climate xwarming ")
	x <- str_replace_all(x, pattern = " (G|g)lobal( - |-| )(W|w)arm[a-z]+ | (G|g)lobal( - |-| )(W|w)arm " , replacement = " global xwarming ")
	x <- str_replace_all(x, pattern = " (W|w)arm[a-z]+( - |-| )(C|c)limate[a-z]+ | (W|w)arm( - |-| )(C|c)limate " , replacement = " xwarming climate ")
	x <- str_replace_all(x, pattern = " (S|s)olid( - |-| )(W|w)aste[a-z]+ | (S|s)olid( - |-| )(W|w)aste " , replacement = " solid xwaste ")
	x <- str_replace_all(x, pattern = " (W|w)aste( - |-| )(D|d)isposal " , replacement = " xwaste disposal ")
	x <- str_replace_all(x, pattern = " (W|w)aste( - |-| )(F|f)acilit[a-z]+ " , replacement = " xwaste facility ")
	x <- str_replace_all(x, pattern = " (W|w)aste( - |-| )(m|M)anagement[a-z]+ | (W|w)aste( - |-| )(m|M)anagement " , replacement = " xwaste management ")
	x <- str_replace_all(x, pattern = " (P|p)retty (W|w)ell " , replacement = " pretty xwell ")
	x <- str_replace_all(x, pattern = " (C|c)ould (W|w)ell " , replacement = " could xwell ")
	x <- str_replace_all(x, pattern = " (D|d)amn (W|w)ell " , replacement = " damn xwell ")
	x <- str_replace_all(x, pattern = " (D|d)eep( - |-| )(W|w)ell " , replacement = " deep xwell ")
	x <- str_replace_all(x, pattern = " (D|d)o (W|w)ell " , replacement = " do xwell ")
	x <- str_replace_all(x, pattern = " (F|f)all[a-z]+ (W|w)ell | (F|f)all (W|w)ell " , replacement = " fall xwell ")
	x <- str_replace_all(x, pattern = " (F|f)ull (W|w)ell " , replacement = " full xwell ")
	x <- str_replace_all(x, pattern = " (H|h)ow (W|w)ell " , replacement = " how xwell ")
	x <- str_replace_all(x, pattern = " (K|k)new (V|v)ery (W|w)ell " , replacement = " knew very xwell ")
	x <- str_replace_all(x, pattern = " (K|k)new (W|w)ell " , replacement = " knew xwell ")
	x <- str_replace_all(x, pattern = " (K|k)now[a-z]+ (V|v)ery (W|w)ell | (K|k)now (V|v)ery (W|w)ell " , replacement = " know very xwell ")
	x <- str_replace_all(x, pattern = " (K|k)now[a-z]+ (W|w)ell | (K|k)now (W|w)ell " , replacement = " know xwell ")
	x <- str_replace_all(x, pattern = " (M|m)ay (V|v)ery (W|w)ell " , replacement = " may very xwell ")
	x <- str_replace_all(x, pattern = " (M|m)ay (W|w)ell " , replacement = " may xwell ")
	x <- str_replace_all(x, pattern = " (M|m)ight (V|v)ery (W|w)ell " , replacement = " might very xwell ")
	x <- str_replace_all(x, pattern = " (M|m)ight (W|w)ell " , replacement = " might xwell ")
	x <- str_replace_all(x, pattern = " (P|p)er( - |-| )(W|w)ell " , replacement = " per xwell ")
	x <- str_replace_all(x, pattern = " (S|s)aid (W|w)ell " , replacement = " said xwell ")
	x <- str_replace_all(x, pattern = " (S|s)urface( - |-| )(W|w)ell " , replacement = " surface xwell ")
	x <- str_replace_all(x, pattern = " (T|t)ears (W|w)ell[a-z]+ | (T|t)ears (W|w)ell " , replacement = " tears xwell ")
	x <- str_replace_all(x, pattern = " (T|t)he (W|w)ell " , replacement = " the xwell ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(A|a)bove[a-z]+ | (W|w)ell( - |-| )(A|a)bove " , replacement = " xwell above ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(A|a)dvised " , replacement = " xwell advised ")
	x <- str_replace_all(x, pattern = " (W|w)ell (A|a)fter " , replacement = " xwell after ")
	x <- str_replace_all(x, pattern = " (W|w)ell (A|a)head " , replacement = " xwell ahead ")
	x <- str_replace_all(x, pattern = " (W|w)ell (A|a)part " , replacement = " xwell apart ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(A|a)rmed " , replacement = " xwell armed ")
	x <- str_replace_all(x, pattern = " (W|w)ell (A|a)ware " , replacement = " xwell aware ")
	x <- str_replace_all(x, pattern = " (W|w)ell (A|a)way " , replacement = " xwell away ")
	x <- str_replace_all(x, pattern = " (W|w)ell (B|b)ack " , replacement = " xwell back ")
	x <- str_replace_all(x, pattern = " (W|w)ell (B|b)e " , replacement = " xwell be ")
	x <- str_replace_all(x, pattern = " (W|w)ell (B|b)efore " , replacement = " xwell before ")
	x <- str_replace_all(x, pattern = " (W|w)ell (B|b)ehind " , replacement = " xwell behind ")
	x <- str_replace_all(x, pattern = " (W|w)ell (B|b)elow " , replacement = " xwell below ")
	x <- str_replace_all(x, pattern = " (W|w)ell (B|b)eyond " , replacement = " xwell beyond ")
	x <- str_replace_all(x, pattern = " (W|w)ell (E|e)nd (U|u)p " , replacement = " xwell end up ")
	x <- str_replace_all(x, pattern = " (W|w)ell (H|h)ave " , replacement = " xwell have ")
	x <- str_replace_all(x, pattern = " (W|w)ell (H|h)idden " , replacement = " xwell hidden ")
	x <- str_replace_all(x, pattern = " (W|w)ell (H|h)ow " , replacement = " xwell how ")
	x <- str_replace_all(x, pattern = " (W|w)ell (I|i)f " , replacement = " xwell if ")
	x <- str_replace_all(x, pattern = " (W|w)ell (I|i)n " , replacement = " xwell in ")
	x <- str_replace_all(x, pattern = " (W|w)ell (I|i)nto " , replacement = " xwell into ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(K|k)ept " , replacement = " xwell kept ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(K|k)now[a-z]+ | (W|w)ell( - |-| )(K|k)now " , replacement = " xwell know ")
	x <- str_replace_all(x, pattern = " (W|w)ell (O|o)ut " , replacement = " xwell out ")
	x <- str_replace_all(x, pattern = " (W|w)ell (O|o)ver " , replacement = " xwell over ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(P|p)ast " , replacement = " xwell past ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(S|s)hort " , replacement = " xwell short ")
	x <- str_replace_all(x, pattern = " (W|w)ell (S|s)o " , replacement = " xwell so ")
	x <- str_replace_all(x, pattern = " (W|w)ell (T|t)hen " , replacement = " xwell then ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(U|u)nder " , replacement = " xwell under ")
	x <- str_replace_all(x, pattern = " (W|w)ell( - |-| )(W|w)ater " , replacement = " xwell water ")
	x <- str_replace_all(x, pattern = " (W|w)ell (Y|y)es " , replacement = " xwell yes ")
	x <- str_replace_all(x, pattern = " (A|a)s (W|w)ell " , replacement = " as xwell ")
	x <- str_replace_all(x, pattern = " (A|a)s x(W|w)ell (T|t)o (D|d)o " , replacement = " as well to do ")
	x <- str_replace_all(x, pattern = " (L|l)ess x(W|w)ell (K|k)nown " , replacement = " less well known ")
	x <- str_replace_all(x, pattern = " (W|w)hack (L|l)oad " , replacement = " xwhack load ")
	x <- str_replace_all(x, pattern = " (W|w)hack (O|o)f " , replacement = " xwhack of ")
	x <- str_replace_all(x, pattern = " (W|w)hack (U|u)pside " , replacement = " xwhack upside ")
	x <- str_replace_all(x, pattern = " (W|w)ild (B|b)ird[a-z]+ | (W|w)ild (B|b)ird " , replacement = " xwild bird ")
	x <- str_replace_all(x, pattern = " (W|w)ild (D|d)uck[a-z]+ | (W|w)ild (D|d)uck " , replacement = " xwild duck ")
	x <- str_replace_all(x, pattern = " (W|w)ild (F|f)lower[a-z]+ | (W|w)ild (F|f)lower " , replacement = " xwild flower ")
	x <- str_replace_all(x, pattern = " (W|w)ild (R|r)apid[a-z]+ | (W|w)ild (R|r)apid " , replacement = " xwild rapid ")
	x <- str_replace_all(x, pattern = " (W|w)ild (S|s)almon[a-z]+ | (W|w)ild (S|s)almon " , replacement = " xwild salmon ")
	x <- str_replace_all(x, pattern = " (W|w)ip[a-z]+( - |-| )(O|o)ut " , replacement = " wipe out ")
	x <- str_replace_all(x, pattern = " (D|d)im( - |-| )(W|w)it " , replacement = " dim xwit ")
	x <- str_replace_all(x, pattern = " (S|s)low( - |-| )(W|w)it " , replacement = " slow xwit ")
	x <- str_replace_all(x, pattern = " ([0-9]+)( - |-| )(W|w)orth" , replacement = " \\1 xworth ")
	x <- str_replace_all(x, pattern = " (W|w)orth( - |-| )([0-9]+)" , replacement = " xworth \\2 ")
	x <- str_replace_all(x, pattern = " (B|b)illion[a-z]+( - |-| )(W|w)orth | (B|b)illion( - |-| )(W|w)orth " , replacement = " billion xworth ")
	x <- str_replace_all(x, pattern = " (D|d)ollars( - |-| )(W|w)orth " , replacement = " dollars xworth ")
	x <- str_replace_all(x, pattern = " (M|m)illion[a-z]+( - |-| )(W|w)orth | (M|m)illion( - |-| )(W|w)orth " , replacement = " million xworth ")
	x <- str_replace_all(x, pattern = " (N|n)et( - |-| )(W|w)orth " , replacement = " net xworth ")
	x <- str_replace_all(x, pattern = " (W|w)orth (A|a) (T|t)otal " , replacement = " xworth a total ")
	x <- str_replace_all(x, pattern = " (W|w)orth (A|a)bout " , replacement = " xworth about ")
	x <- str_replace_all(x, pattern = " (W|w)orth (A|a)n (E|e)stimated " , replacement = " xworth an estimated ")
	x <- str_replace_all(x, pattern = " (W|w)orth (A|a)s (M|m)uch (A|a)s " , replacement = " xworth as much as ")
	x <- str_replace_all(x, pattern = " (W|w)orth (L|l)ess (T|t)han " , replacement = " xworth less than ")
	x <- str_replace_all(x, pattern = " (W|w)orth (M|m)ore (T|t)han " , replacement = " xworth more than ")
	x <- str_replace_all(x, pattern = " (W|w)orth (U|u)p (T|t)o " , replacement = " xworth up to ")
	x <- str_replace_all(x, pattern = " (R|r)ight[a-z]+( - |-| )(A|a)nd( - |-| )(W|w)rong[a-z]+ | (R|r)ight( - |-| )(A|a)nd( - |-| )(W|w)rong " , replacement = " xright and xwrong ")
	x <- str_replace_all(x, pattern = " (R|r)ight[a-z]+( - |-| )(O|o)r( - |-| )(W|w)rong[a-z]+ | (R|r)ight( - |-| )(O|o)r( - |-| )(W|w)rong " , replacement = " xright or xwrong ")
	x <- str_replace_all(x, pattern = " (S|s)hort( - |-| )(T|t)erm( - |-| )(V|v)ision " , replacement = " xshort term xvision ")
	x <- str_replace_all(x, pattern = " (O|o)ver( - |-| )(Z|z)ealous[a-z]+ | (O|o)ver( - |-| )(Z|z)ealous " , replacement = " overzealous ")
     x <- str_trim(x, side = "both")  ## This removes the extraneous space added to beginning and end by first two lines
}



#----------------------------------------------------------------------------
#
#	Optional Capital Letter Pre-Processing Functions - Mark proper nouns (to remove from sentiment counts)
#
#----------------------------------------------------------------------------

mark_proper_nouns <- function(x) {
     require(stringr)
	x <- str_replace_all(x, pattern = "([A-Za-z0-9'] )([A-Z])", replacement = "\\1\\2_")
	x <- str_replace_all(x, pattern = "(\\()(| )([A-Z])", replacement = "\\1\\2\\3_")
	x <- str_replace_all(x, pattern = "(,)(| )([A-Z])", replacement = "\\1 \\3_")
	x <- str_replace_all(x, pattern = "([_] )([A-Z])", replacement = "\\1\\2_")
	# Note: the following line removes extraneous underscores, if a word is marked by an underscore more than once by previous lines
	x <- str_replace_all(x, pattern = "([A-Z]_)(____|___|__|_)", replacement = "\\1")
}




